Class: Courier::Models::AudienceFilterConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/audience_filter_config.rb,
sig/courier/models/audience_filter_config.rbs

Defined Under Namespace

Modules: Operator

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filters:, operator: nil) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::AudienceFilterConfig for more details.

Filter configuration for audience membership containing an array of filter rules

Parameters:



# File 'lib/courier/models/audience_filter_config.rb', line 20

Instance Attribute Details

#filtersArray<Courier::Models::FilterConfig>

Array of filter rules (single conditions or nested groups)

Parameters:

Returns:



10
# File 'lib/courier/models/audience_filter_config.rb', line 10

required :filters, -> { Courier::Internal::Type::ArrayOf[Courier::FilterConfig] }

#operatorSymbol, ...

The logical operator (AND/OR) combining the rules in filters. Required when filters contains more than one rule. If omitted, the top-level operator field on the request is used instead.



18
# File 'lib/courier/models/audience_filter_config.rb', line 18

optional :operator, enum: -> { Courier::AudienceFilterConfig::Operator }

Instance Method Details

#to_hash{

Returns:

  • ({)


23
# File 'sig/courier/models/audience_filter_config.rbs', line 23

def to_hash: -> {