Class: Courier::Models::AuthIssueTokenParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/courier/models/auth_issue_token_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(expires_in:, scope:, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::AuthIssueTokenParams for more details.

Parameters:

  • expires_in (String)

    Duration for token expiration. Accepts various time formats:

  • scope (String)

    Available scopes:

  • request_options (Courier::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/courier/models/auth_issue_token_params.rb', line 46

Instance Attribute Details

#expires_inString

Duration for token expiration. Accepts various time formats:

  • "2 hours" - 2 hours from now
  • "1d" - 1 day
  • "3 days" - 3 days
  • "10h" - 10 hours
  • "2.5 hrs" - 2.5 hours
  • "1m" - 1 minute
  • "5s" - 5 seconds
  • "1y" - 1 year

Returns:

  • (String)


23
# File 'lib/courier/models/auth_issue_token_params.rb', line 23

required :expires_in, String

#scopeString

Available scopes:

  • user_id:<user-id> - Defines which user the token will be scoped to. Multiple can be listed if needed. Ex user_id:pigeon user_id:bluebird.
  • read:messages - Read messages.
  • read:user-tokens - Read user push tokens.
  • write:user-tokens - Write user push tokens.
  • read:brands[:<brand_id>] - Read brands, optionally restricted to a specific brand_id. Examples read:brands, read:brands:my_brand.
  • write:brands[:<brand_id>] - Write brands, optionally restricted to a specific brand_id. Examples write:brands, write:brands:my_brand.
  • inbox:read:messages - Read inbox messages.
  • inbox:write:events - Write inbox events, such as mark message as read.
  • read:preferences - Read user preferences.
  • write:preferences - Write user preferences. Example: user_id:user123 write:user-tokens inbox:read:messages inbox:write:events read:preferences write:preferences read:brands

Returns:

  • (String)


44
# File 'lib/courier/models/auth_issue_token_params.rb', line 44

required :scope, String