Class: Courier::Models::AutomationRunListItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/automation_run_list_item.rb,
sig/courier/models/automation_run_list_item.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(run_id:, source:, created_at: nil, status: nil, template_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::AutomationRunListItem for more details.

An Automation run as it appears in a list response.

Parameters:

  • run_id (String)

    A unique identifier representing the run.

  • source (Array<String>)

    Internal provenance strings describing what started the run, e.g. `invoke/<templ

  • created_at (String) (defaults to: nil)

    When the run started, as an ISO 8601 timestamp.

  • status (String) (defaults to: nil)

    The state of the run: PROCESSING, PROCESSED, WAITING, CANCELED, ERROR,

  • template_id (String) (defaults to: nil)

    The id of the Automation Template this run belongs to.



# File 'lib/courier/models/automation_run_list_item.rb', line 40

Instance Attribute Details

#created_atString?

When the run started, as an ISO 8601 timestamp.

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/courier/models/automation_run_list_item.rb', line 24

optional :created_at, String

#run_idString

A unique identifier representing the run.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/courier/models/automation_run_list_item.rb', line 10

required :run_id, String

#sourceArray<String>

Internal provenance strings describing what started the run, e.g. invoke/<template_id> or segment/page/Pricing Page. Diagnostic only — the format is unstable and should not be parsed.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


18
# File 'lib/courier/models/automation_run_list_item.rb', line 18

required :source, Courier::Internal::Type::ArrayOf[String]

#statusString?

The state of the run: PROCESSING, PROCESSED, WAITING, CANCELED, ERROR, THROTTLED, or NOT PROCESSED. Not an enum — new values have been added before.

Parameters:

  • (String)

Returns:

  • (String, nil)


32
# File 'lib/courier/models/automation_run_list_item.rb', line 32

optional :status, String

#template_idString?

The id of the Automation Template this run belongs to.

Parameters:

  • (String)

Returns:

  • (String, nil)


38
# File 'lib/courier/models/automation_run_list_item.rb', line 38

optional :template_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


37
# File 'sig/courier/models/automation_run_list_item.rbs', line 37

def to_hash: -> {