Class: Courier::Models::CancelJourneyResponse::RunIDBranch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::CancelJourneyResponse::RunIDBranch
- Defined in:
- lib/courier/models/cancel_journey_response.rb,
sig/courier/models/cancel_journey_response.rbs
Instance Attribute Summary collapse
- #run_id ⇒ String
-
#status ⇒ String
The run's resulting status.
Instance Method Summary collapse
-
#initialize(run_id:, status:) ⇒ RunIDBranch
constructor
Some parameter documentations has been truncated, see RunIDBranch for more details.
- #to_hash ⇒ { run_id: String, status: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(run_id:, status:) ⇒ RunIDBranch
Some parameter documentations has been truncated, see Courier::Models::CancelJourneyResponse::RunIDBranch for more details.
|
|
# File 'lib/courier/models/cancel_journey_response.rb', line 42
|
Instance Attribute Details
#run_id ⇒ String
32 |
# File 'lib/courier/models/cancel_journey_response.rb', line 32 required :run_id, String |
#status ⇒ String
The run's resulting status. CANCELED when the run was active and has been
canceled; PROCESSED or ERROR when the run had already finished and was left
unchanged; CANCELED for an already-canceled run.
40 |
# File 'lib/courier/models/cancel_journey_response.rb', line 40 required :status, String |
Instance Method Details
#to_hash ⇒ { run_id: String, status: String }
29 |
# File 'sig/courier/models/cancel_journey_response.rbs', line 29
def to_hash: -> { run_id: String, status: String }
|