Class: Courier::Models::CreateDeviceSetRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::CreateDeviceSetRequest
- Defined in:
- lib/courier/models/create_device_set_request.rb,
sig/courier/models/create_device_set_request.rbs
Direct Known Subclasses
Instance Attribute Summary collapse
-
#device_ids ⇒ Array<String>
The devices the set contains, by
PreviewDevice.id. -
#name ⇒ String
Human-readable name.
Instance Method Summary collapse
-
#initialize(device_ids:, name:) ⇒ CreateDeviceSetRequest
constructor
Request body for creating or replacing a device set.
- #to_hash ⇒ { device_ids: ::Array[String], name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(device_ids:, name:) ⇒ CreateDeviceSetRequest
Request body for creating or replacing a device set. A full replace, not a patch — both fields are always written.
|
|
# File 'lib/courier/models/create_device_set_request.rb', line 18
|
Instance Attribute Details
#device_ids ⇒ Array<String>
The devices the set contains, by PreviewDevice.id. At least one is required.
10 |
# File 'lib/courier/models/create_device_set_request.rb', line 10 required :device_ids, Courier::Internal::Type::ArrayOf[String] |
#name ⇒ String
Human-readable name.
16 |
# File 'lib/courier/models/create_device_set_request.rb', line 16 required :name, String |
Instance Method Details
#to_hash ⇒ { device_ids: ::Array[String], name: String }
13 |
# File 'sig/courier/models/create_device_set_request.rbs', line 13
def to_hash: -> { device_ids: ::Array[String], name: String }
|