Class: Courier::Models::DigestCategory
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::DigestCategory
- Defined in:
- lib/courier/models/digest_category.rb
Defined Under Namespace
Modules: Retain
Instance Attribute Summary collapse
-
#category_key ⇒ String
The key that identifies the category within the digest.
-
#retain ⇒ Symbol, Courier::Models::DigestCategory::Retain
Which events to keep when the number of events exceeds the retention limit for the category.
-
#sort_key ⇒ String?
The data key used to order events when ‘retain` is `highest` or `lowest`.
Instance Method Summary collapse
-
#initialize(category_key:, retain:, sort_key: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DigestCategory for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(category_key:, retain:, sort_key: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::DigestCategory for more details.
|
|
# File 'lib/courier/models/digest_category.rb', line 25
|
Instance Attribute Details
#category_key ⇒ String
The key that identifies the category within the digest.
10 |
# File 'lib/courier/models/digest_category.rb', line 10 required :category_key, String |
#retain ⇒ Symbol, Courier::Models::DigestCategory::Retain
Which events to keep when the number of events exceeds the retention limit for the category.
17 |
# File 'lib/courier/models/digest_category.rb', line 17 required :retain, enum: -> { Courier::DigestCategory::Retain } |
#sort_key ⇒ String?
The data key used to order events when ‘retain` is `highest` or `lowest`.
23 |
# File 'lib/courier/models/digest_category.rb', line 23 optional :sort_key, String |