Class: Courier::Models::DigestInstanceListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::DigestInstanceListResponse
- Defined in:
- lib/courier/models/digest_instance_list_response.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#cursor ⇒ String?
A cursor token for fetching the next page of results, or null when there are none.
-
#has_more ⇒ Boolean
Whether there are more digest instances to fetch using the cursor.
-
#items ⇒ Array<Courier::Models::DigestInstance>
The digest instances for this page of results.
-
#next_url ⇒ String?
The path to fetch the next page of results, or null when there are none.
-
#type ⇒ Symbol, Courier::Models::DigestInstanceListResponse::Type
Always ‘list` for a paginated list response.
-
#url ⇒ String?
The path of the current request.
Instance Method Summary collapse
-
#initialize(has_more:, items:, type:, cursor: nil, next_url: nil, url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DigestInstanceListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(has_more:, items:, type:, cursor: nil, next_url: nil, url: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::DigestInstanceListResponse for more details.
|
|
# File 'lib/courier/models/digest_instance_list_response.rb', line 43
|
Instance Attribute Details
#cursor ⇒ String?
A cursor token for fetching the next page of results, or null when there are none.
29 |
# File 'lib/courier/models/digest_instance_list_response.rb', line 29 optional :cursor, String, nil?: true |
#has_more ⇒ Boolean
Whether there are more digest instances to fetch using the cursor.
10 |
# File 'lib/courier/models/digest_instance_list_response.rb', line 10 required :has_more, Courier::Internal::Type::Boolean |
#items ⇒ Array<Courier::Models::DigestInstance>
The digest instances for this page of results.
16 |
# File 'lib/courier/models/digest_instance_list_response.rb', line 16 required :items, -> { Courier::Internal::Type::ArrayOf[Courier::DigestInstance] } |
#next_url ⇒ String?
The path to fetch the next page of results, or null when there are none.
35 |
# File 'lib/courier/models/digest_instance_list_response.rb', line 35 optional :next_url, String, nil?: true |
#type ⇒ Symbol, Courier::Models::DigestInstanceListResponse::Type
Always ‘list` for a paginated list response.
22 |
# File 'lib/courier/models/digest_instance_list_response.rb', line 22 required :type, enum: -> { Courier::DigestInstanceListResponse::Type } |
#url ⇒ String?
The path of the current request.
41 |
# File 'lib/courier/models/digest_instance_list_response.rb', line 41 optional :url, String |