Class: Courier::Models::ElementalMetaNode
- Inherits:
-
ElementalBaseNode
- Object
- Internal::Type::BaseModel
- ElementalBaseNode
- Courier::Models::ElementalMetaNode
- Defined in:
- lib/courier/models/elemental_meta_node.rb,
sig/courier/models/elemental_meta_node.rbs
Direct Known Subclasses
Instance Attribute Summary collapse
-
#title ⇒ String?
The title to be displayed by supported channels.
Attributes inherited from ElementalBaseNode
Instance Method Summary collapse
-
#initialize(title: nil) ⇒ ElementalMetaNode
constructor
Some parameter documentations has been truncated, see ElementalMetaNode for more details.
- #to_hash ⇒ { title: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(title: nil) ⇒ ElementalMetaNode
Some parameter documentations has been truncated, see Courier::Models::ElementalMetaNode for more details.
The meta element contains information describing the notification that may be used by a particular channel or provider. One important field is the title field which will be used as the title for channels that support it.
|
|
# File 'lib/courier/models/elemental_meta_node.rb', line 12
|
Instance Attribute Details
#title ⇒ String?
The title to be displayed by supported channels. For example, the email subject.
10 |
# File 'lib/courier/models/elemental_meta_node.rb', line 10 optional :title, String, nil?: true |
Instance Method Details
#to_hash ⇒ { title: String? }
12 |
# File 'sig/courier/models/elemental_meta_node.rbs', line 12
def to_hash: -> { title: String? }
|