Module: Courier::Models::ElementalMetaNodeWithType::Type

Extended by:
Internal::Type::Enum
Defined in:
lib/courier/models/elemental_meta_node_with_type.rb,
sig/courier/models/elemental_meta_node_with_type.rbs

Constant Summary collapse

META =

Returns:

  • (:meta)
:meta

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/courier/models/elemental_meta_node_with_type.rb', line 23

Instance Method Details

#initialize(type: nil) ⇒ Object

The meta element contains information describing the notification that may be used by a particular channel or provider. One important field is the title field which will be used as the title for channels that support it.

Parameters:



18
19
20
21
22
23
24
25
# File 'lib/courier/models/elemental_meta_node_with_type.rb', line 18

module Type
  extend Courier::Internal::Type::Enum

  META = :meta

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Courier::Models::ElementalMetaNodeWithType::type_]

Returns:

  • (::Array[Courier::Models::ElementalMetaNodeWithType::type_])


28
# File 'sig/courier/models/elemental_meta_node_with_type.rbs', line 28

def self?.values: -> ::Array[Courier::Models::ElementalMetaNodeWithType::type_]