Module: Courier::Models::ElementalNodeNonChannel::UnionMember1::Type

Extended by:
Internal::Type::Enum
Defined in:
lib/courier/models/elemental_node_non_channel.rb,
sig/courier/models/elemental_node_non_channel.rbs

Constant Summary collapse

META =

Returns:

  • (:meta)
:meta

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(type: nil) ⇒ Object

The meta element contains information describing the notification that may be used by a particular channel or provider. One important field is the title field which will be used as the title for channels that support it.

Parameters:



67
68
69
70
71
72
73
74
# File 'lib/courier/models/elemental_node_non_channel.rb', line 67

module Type
  extend Courier::Internal::Type::Enum

  META = :meta

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values ⇒ ::Array[Courier::Models::ElementalNodeNonChannel::UnionMember1::type_]

Returns:

  • (::Array[Courier::Models::ElementalNodeNonChannel::UnionMember1::type_])


69
# File 'sig/courier/models/elemental_node_non_channel.rbs', line 69

def self?.values: -> ::Array[Courier::Models::ElementalNodeNonChannel::UnionMember1::type_]