Class: Courier::Models::EmailFooter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/email_footer.rb,
sig/courier/models/email_footer.rbs

Defined Under Namespace

Classes: Social

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(inherit_default: nil, markdown: nil, social: nil) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::EmailFooter for more details.

Parameters:

  • inherit_default (Boolean, nil) (defaults to: nil)
  • markdown (String, nil) (defaults to: nil) —

    The footer body, as markdown. This is the field the API returns and accepts; it

  • social (Courier::Models::EmailFooter::Social, nil) (defaults to: nil) —

    Social links rendered in the email footer.



# File 'lib/courier/models/email_footer.rb', line 25

Instance Attribute Details

#inherit_default ⇒ Boolean?

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


9
# File 'lib/courier/models/email_footer.rb', line 9

optional :inherit_default, Courier::Internal::Type::Boolean, api_name: :inheritDefault, nil?: true

#markdown ⇒ String?

The footer body, as markdown. This is the field the API returns and accepts; it is omitted entirely when no footer body is set. Sending null is accepted and treated as no footer body.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


17
# File 'lib/courier/models/email_footer.rb', line 17

optional :markdown, String, nil?: true

#social ⇒ Courier::Models::EmailFooter::Social?

Social links rendered in the email footer.

Parameters:

  • value (Courier::EmailFooter::Social, nil)

Returns:



23
# File 'lib/courier/models/email_footer.rb', line 23

optional :social, -> { Courier::EmailFooter::Social }, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


23
# File 'sig/courier/models/email_footer.rbs', line 23

def to_hash: -> {