Class: Courier::Models::InboundBulkMessageUser

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/inbound_bulk_message_user.rb

Direct Known Subclasses

BulkListUsersResponse::Item

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data: nil, preferences: nil, profile: nil, recipient: nil, to: nil) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::InboundBulkMessageUser for more details.



# File 'lib/courier/models/inbound_bulk_message_user.rb', line 39


Instance Attribute Details

#dataObject?

User-specific data that will be merged with message.data



10
# File 'lib/courier/models/inbound_bulk_message_user.rb', line 10

optional :data, Courier::Internal::Type::Unknown

#preferencesCourier::Models::RecipientPreferences?



15
# File 'lib/courier/models/inbound_bulk_message_user.rb', line 15

optional :preferences, -> { Courier::RecipientPreferences }, nil?: true

#profileHash{Symbol=>Object}?

User profile information. For email-based bulk jobs, profile.email is required for provider routing to determine if the message can be delivered. The email address should be provided here rather than in to.email.



23
# File 'lib/courier/models/inbound_bulk_message_user.rb', line 23

optional :profile, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown], nil?: true

#recipientString?

User ID (legacy field, use profile or to.user_id instead)



29
# File 'lib/courier/models/inbound_bulk_message_user.rb', line 29

optional :recipient, String, nil?: true

#toCourier::Models::UserRecipient?

Optional recipient information. Note: For email provider routing, use profile.email instead of to.email. The to field is primarily used for recipient identification and data merging.



37
# File 'lib/courier/models/inbound_bulk_message_user.rb', line 37

optional :to, -> { Courier::UserRecipient }, nil?: true