Class: Courier::Models::JourneyFetchGetDeleteNode
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::JourneyFetchGetDeleteNode
- Defined in:
- lib/courier/models/journey_fetch_get_delete_node.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#conditions ⇒ Array<String>, ...
Condition spec for a journey node.
- #headers ⇒ Hash{Symbol=>String}?
- #id ⇒ String?
-
#merge_strategy ⇒ Symbol, Courier::Models::JourneyMergeStrategy
Strategy for merging a fetch response into the journey run state.
- #method_ ⇒ Symbol, Courier::Models::JourneyFetchGetDeleteNode::Method
- #query_params ⇒ Hash{Symbol=>String}?
-
#response_schema ⇒ Hash{Symbol=>Object}?
A JSONSchema object (Draft-07-compatible).
- #type ⇒ Symbol, Courier::Models::JourneyFetchGetDeleteNode::Type
- #url ⇒ String
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(merge_strategy:, method_:, type:, url:, id: nil, conditions: nil, headers: nil, query_params: nil, response_schema: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see JourneyFetchGetDeleteNode for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(merge_strategy:, method_:, type:, url:, id: nil, conditions: nil, headers: nil, query_params: nil, response_schema: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::JourneyFetchGetDeleteNode for more details.
Issue an HTTP GET or DELETE request and merge the response into the journey state per ‘merge_strategy`.
|
|
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 56
|
Instance Attribute Details
#conditions ⇒ Array<String>, ...
Condition spec for a journey node. Accepts a single condition atom, an AND/OR group, or an AND/OR nested group. Omit the ‘conditions` property entirely to express “no conditions”.
38 |
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 38 optional :conditions, union: -> { Courier::JourneyConditionsField } |
#headers ⇒ Hash{Symbol=>String}?
43 |
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 43 optional :headers, Courier::Internal::Type::HashOf[String] |
#id ⇒ String?
30 |
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 30 optional :id, String |
#merge_strategy ⇒ Symbol, Courier::Models::JourneyMergeStrategy
Strategy for merging a fetch response into the journey run state.
10 |
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 10 required :merge_strategy, enum: -> { Courier::JourneyMergeStrategy } |
#method_ ⇒ Symbol, Courier::Models::JourneyFetchGetDeleteNode::Method
15 |
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 15 required :method_, enum: -> { Courier::JourneyFetchGetDeleteNode::Method }, api_name: :method |
#query_params ⇒ Hash{Symbol=>String}?
48 |
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 48 optional :query_params, Courier::Internal::Type::HashOf[String] |
#response_schema ⇒ Hash{Symbol=>Object}?
A JSONSchema object (Draft-07-compatible). Validated at runtime by Ajv.
54 |
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 54 optional :response_schema, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown] |
#type ⇒ Symbol, Courier::Models::JourneyFetchGetDeleteNode::Type
20 |
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 20 required :type, enum: -> { Courier::JourneyFetchGetDeleteNode::Type } |
#url ⇒ String
25 |
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 25 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/courier/models/journey_fetch_get_delete_node.rb', line 88
|