Class: Courier::Models::JourneyFetchPostPutNode
Defined Under Namespace
Modules: Method, Type
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(merge_strategy:, method_:, type:, url:, id: nil, body: nil, conditions: nil, headers: nil, query_params: nil, response_schema: nil) ⇒ Object
Some parameter documentations has been truncated, see
Courier::Models::JourneyFetchPostPutNode for more details.
Issue an HTTP POST or PUT request with a body and merge the response into the
journey state per merge_strategy.
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 61
|
Instance Attribute Details
#body ⇒ String?
35
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 35
optional :body, String
|
#conditions ⇒ Array<String>, ...
Condition spec for a journey node. Accepts a single condition atom, an AND/OR
group, or an AND/OR nested group. Omit the conditions property entirely to
express "no conditions".
43
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 43
optional :conditions, union: -> { Courier::JourneyConditionsField }
|
48
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 48
optional :headers, Courier::Internal::Type::HashOf[String]
|
#id ⇒ String?
30
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 30
optional :id, String
|
Strategy for merging a fetch response into the journey run state.
10
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 10
required :merge_strategy, enum: -> { Courier::JourneyMergeStrategy }
|
15
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 15
required :method_, enum: -> { Courier::JourneyFetchPostPutNode::Method }, api_name: :method
|
#query_params ⇒ Hash{Symbol=>String}?
53
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 53
optional :query_params, Courier::Internal::Type::HashOf[String]
|
#response_schema ⇒ Hash{Symbol=>Object}?
A JSONSchema object (Draft-07-compatible). Validated at runtime by Ajv.
59
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 59
optional :response_schema, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown]
|
20
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 20
required :type, enum: -> { Courier::JourneyFetchPostPutNode::Type }
|
#url ⇒ String
25
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 25
required :url, String
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 95
|
Instance Method Details
#to_hash ⇒ {
65
|
# File 'sig/courier/models/journey_fetch_post_put_node.rbs', line 65
def to_hash: -> {
|