Module: Courier::Models::JourneyNode

Extended by:
Internal::Type::Union
Defined in:
lib/courier/models/journey_node.rb,
sig/courier/models/journey_node.rbs

Overview

A single node in a journey DAG. Discriminated by type, with a secondary discriminator on some variants (trigger_type for trigger, mode for delay, method for fetch, scope for throttle).

Defined Under Namespace

Classes: JourneyAddToDigestNode, JourneyBatchNode, JourneyBranchNode

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[Courier::Models::journey_node]

Returns:

  • (::Array[Courier::Models::journey_node])


293
# File 'sig/courier/models/journey_node.rbs', line 293

def self?.variants: -> ::Array[Courier::Models::journey_node]