Class: Courier::Models::JourneyNode::JourneyBatchNode::Retain
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::JourneyNode::JourneyBatchNode::Retain
- Defined in:
- lib/courier/models/journey_node.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
- #count ⇒ Integer
-
#sort_key ⇒ String?
Dot-path into the event payload (e.g. ‘data.priority`).
- #type ⇒ Symbol, Courier::Models::JourneyNode::JourneyBatchNode::Retain::Type
Instance Method Summary collapse
-
#initialize(count:, type:, sort_key: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Retain for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(count:, type:, sort_key: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::JourneyNode::JourneyBatchNode::Retain for more details.
How to select which collected events to retain in the aggregated payload when the batch releases.
|
|
# File 'lib/courier/models/journey_node.rb', line 155
|
Instance Attribute Details
#count ⇒ Integer
141 |
# File 'lib/courier/models/journey_node.rb', line 141 required :count, Integer |
#sort_key ⇒ String?
Dot-path into the event payload (e.g. ‘data.priority`). Required when `type` is `highest` or `lowest`.
153 |
# File 'lib/courier/models/journey_node.rb', line 153 optional :sort_key, String |
#type ⇒ Symbol, Courier::Models::JourneyNode::JourneyBatchNode::Retain::Type
146 |
# File 'lib/courier/models/journey_node.rb', line 146 required :type, enum: -> { Courier::JourneyNode::JourneyBatchNode::Retain::Type } |