Class: Courier::Models::JourneyTemplateCreateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::JourneyTemplateCreateRequest
- Defined in:
- lib/courier/models/journey_template_create_request.rb
Direct Known Subclasses
Defined Under Namespace
Classes: Notification
Instance Attribute Summary collapse
- #channel ⇒ String
- #notification ⇒ Courier::Models::JourneyTemplateCreateRequest::Notification
- #provider_key ⇒ String?
- #state ⇒ String?
Instance Method Summary collapse
-
#initialize(channel:, notification:, provider_key: nil, state: nil) ⇒ Object
constructor
Request body for creating a notification template scoped to a journey.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channel:, notification:, provider_key: nil, state: nil) ⇒ Object
Request body for creating a notification template scoped to a journey.
|
|
# File 'lib/courier/models/journey_template_create_request.rb', line 26
|
Instance Attribute Details
#channel ⇒ String
9 |
# File 'lib/courier/models/journey_template_create_request.rb', line 9 required :channel, String |
#notification ⇒ Courier::Models::JourneyTemplateCreateRequest::Notification
14 |
# File 'lib/courier/models/journey_template_create_request.rb', line 14 required :notification, -> { Courier::JourneyTemplateCreateRequest::Notification } |
#provider_key ⇒ String?
19 |
# File 'lib/courier/models/journey_template_create_request.rb', line 19 optional :provider_key, String, api_name: :providerKey |
#state ⇒ String?
24 |
# File 'lib/courier/models/journey_template_create_request.rb', line 24 optional :state, String |