Class: Courier::Models::JourneysInvokeRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/journeys_invoke_request.rb

Direct Known Subclasses

JourneyInvokeParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data: nil, profile: nil, user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::JourneysInvokeRequest for more details.

Request body for invoking a journey. Requires either a user identifier or a profile with contact information. User identifiers can be provided via user_id field, or resolved from profile/data objects (user_id, userId, or anonymousId fields).

Parameters:

  • (defaults to: nil)

    Data payload passed to the journey. The expected shape can be predefined using t

  • (defaults to: nil)

    Profile data for the user. Can contain contact information (email, phone_number)

  • (defaults to: nil)

    A unique identifier for the user. If not provided, the system will attempt to re



# File 'lib/courier/models/journeys_invoke_request.rb', line 33


Instance Attribute Details

#dataHash{Symbol=>Object}?

Data payload passed to the journey. The expected shape can be predefined using the schema builder in the journey editor. This data is available in journey steps for condition evaluation and template variable interpolation. Can also contain user identifiers (user_id, userId, anonymousId) if not provided elsewhere.

Returns:



14
# File 'lib/courier/models/journeys_invoke_request.rb', line 14

optional :data, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown]

#profileHash{Symbol=>Object}?

Profile data for the user. Can contain contact information (email, phone_number), user identifiers (user_id, userId, anonymousId), or any custom profile fields. Profile fields are merged with any existing stored profile for the user. Include context.tenant_id to load a tenant-scoped profile for multi-tenant scenarios.

Returns:



24
# File 'lib/courier/models/journeys_invoke_request.rb', line 24

optional :profile, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown]

#user_idString?

A unique identifier for the user. If not provided, the system will attempt to resolve the user identifier from profile or data objects.

Returns:



31
# File 'lib/courier/models/journeys_invoke_request.rb', line 31

optional :user_id, String