Class: Courier::Models::MessageDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::MessageDetails
- Defined in:
- lib/courier/models/message_details.rb
Overview
Direct Known Subclasses
Defined Under Namespace
Instance Attribute Summary collapse
-
#clicked ⇒ Integer?
A UTC timestamp at which the recipient clicked on a tracked link for the first time.
-
#delivered ⇒ Integer?
A UTC timestamp at which the Integration provider delivered the message.
-
#enqueued ⇒ Integer
A UTC timestamp at which Courier received the message request.
-
#error ⇒ String?
A message describing the error that occurred.
-
#event ⇒ String
A unique identifier associated with the event of the delivered message.
-
#id ⇒ String
A unique identifier associated with the message you wish to retrieve (results from a send).
-
#notification ⇒ String
A unique identifier associated with the notification of the delivered message.
-
#opened ⇒ Integer?
A UTC timestamp at which the recipient opened a message for the first time.
-
#reason ⇒ Symbol, ...
The reason for the current status of the message.
-
#recipient ⇒ String
A unique identifier associated with the recipient of the delivered message.
-
#sent ⇒ Integer?
A UTC timestamp at which Courier passed the message to the Integration provider.
-
#status ⇒ Symbol, Courier::Models::MessageDetails::Status
The current status of the message.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, enqueued:, event:, notification:, recipient:, status:, clicked: nil, delivered: nil, error: nil, opened: nil, reason: nil, sent: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessageDetails for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, enqueued:, event:, notification:, recipient:, status:, clicked: nil, delivered: nil, error: nil, opened: nil, reason: nil, sent: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::MessageDetails for more details.
|
|
# File 'lib/courier/models/message_details.rb', line 85
|
Instance Attribute Details
#clicked ⇒ Integer?
A UTC timestamp at which the recipient clicked on a tracked link for the first time. Stored as a millisecond representation of the Unix epoch.
50 |
# File 'lib/courier/models/message_details.rb', line 50 optional :clicked, Integer |
#delivered ⇒ Integer?
A UTC timestamp at which the Integration provider delivered the message. Stored as a millisecond representation of the Unix epoch.
57 |
# File 'lib/courier/models/message_details.rb', line 57 optional :delivered, Integer |
#enqueued ⇒ Integer
A UTC timestamp at which Courier received the message request. Stored as a millisecond representation of the Unix epoch.
19 |
# File 'lib/courier/models/message_details.rb', line 19 required :enqueued, Integer |
#error ⇒ String?
A message describing the error that occurred.
63 |
# File 'lib/courier/models/message_details.rb', line 63 optional :error, String, nil?: true |
#event ⇒ String
A unique identifier associated with the event of the delivered message.
25 |
# File 'lib/courier/models/message_details.rb', line 25 required :event, String |
#id ⇒ String
A unique identifier associated with the message you wish to retrieve (results from a send).
12 |
# File 'lib/courier/models/message_details.rb', line 12 required :id, String |
#notification ⇒ String
A unique identifier associated with the notification of the delivered message.
31 |
# File 'lib/courier/models/message_details.rb', line 31 required :notification, String |
#opened ⇒ Integer?
A UTC timestamp at which the recipient opened a message for the first time. Stored as a millisecond representation of the Unix epoch.
70 |
# File 'lib/courier/models/message_details.rb', line 70 optional :opened, Integer |
#reason ⇒ Symbol, ...
The reason for the current status of the message.
76 |
# File 'lib/courier/models/message_details.rb', line 76 optional :reason, enum: -> { Courier::MessageDetails::Reason }, nil?: true |
#recipient ⇒ String
A unique identifier associated with the recipient of the delivered message.
37 |
# File 'lib/courier/models/message_details.rb', line 37 required :recipient, String |
#sent ⇒ Integer?
A UTC timestamp at which Courier passed the message to the Integration provider. Stored as a millisecond representation of the Unix epoch.
83 |
# File 'lib/courier/models/message_details.rb', line 83 optional :sent, Integer |
#status ⇒ Symbol, Courier::Models::MessageDetails::Status
The current status of the message.
43 |
# File 'lib/courier/models/message_details.rb', line 43 required :status, enum: -> { Courier::MessageDetails::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/courier/models/message_details.rb', line 135
|