Class: Courier::Models::NotificationContentPutRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::NotificationContentPutRequest
- Defined in:
- lib/courier/models/notification_content_put_request.rb
Direct Known Subclasses
Defined Under Namespace
Classes: Content
Instance Attribute Summary collapse
-
#content ⇒ Courier::Models::NotificationContentPutRequest::Content
Elemental content payload.
-
#state ⇒ Symbol, ...
Template state.
Instance Method Summary collapse
-
#initialize(content:, state: nil) ⇒ Object
constructor
Request body for replacing the elemental content of a notification template.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content:, state: nil) ⇒ Object
Request body for replacing the elemental content of a notification template.
|
|
# File 'lib/courier/models/notification_content_put_request.rb', line 18
|
Instance Attribute Details
#content ⇒ Courier::Models::NotificationContentPutRequest::Content
Elemental content payload. The server defaults version when omitted.
10 |
# File 'lib/courier/models/notification_content_put_request.rb', line 10 required :content, -> { Courier::NotificationContentPutRequest::Content } |
#state ⇒ Symbol, ...
Template state. Defaults to DRAFT.
16 |
# File 'lib/courier/models/notification_content_put_request.rb', line 16 optional :state, enum: -> { Courier::NotificationTemplateState } |