Class: Courier::Models::NotificationListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::NotificationListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/courier/models/notification_list_params.rb,
sig/courier/models/notification_list_params.rbs
Overview
Instance Attribute Summary collapse
-
#cursor ⇒ String?
Opaque pagination cursor from a previous response.
-
#event_id ⇒ String?
Filter to templates linked to this event map ID.
-
#notes ⇒ Boolean?
Include template notes in the response.
-
#tags ⇒ String?
Comma-delimited list of tag names.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(cursor: nil, event_id: nil, notes: nil, tags: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see NotificationListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cursor: nil, event_id: nil, notes: nil, tags: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::NotificationListParams for more details.
|
|
# File 'lib/courier/models/notification_list_params.rb', line 36
|
Instance Attribute Details
#cursor ⇒ String?
Opaque pagination cursor from a previous response. Omit for the first page.
14 |
# File 'lib/courier/models/notification_list_params.rb', line 14 optional :cursor, String, nil?: true |
#event_id ⇒ String?
Filter to templates linked to this event map ID.
20 |
# File 'lib/courier/models/notification_list_params.rb', line 20 optional :event_id, String |
#notes ⇒ Boolean?
Include template notes in the response. Only applies to legacy templates.
26 |
# File 'lib/courier/models/notification_list_params.rb', line 26 optional :notes, Courier::Internal::Type::Boolean, nil?: true |
#tags ⇒ String?
Comma-delimited list of tag names. Only templates carrying all of the listed tags are returned. Matching is case-insensitive. Filtering is applied before pagination.
34 |
# File 'lib/courier/models/notification_list_params.rb', line 34 optional :tags, String |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/courier/models/notification_list_params.rbs', line 31
def to_hash: -> {
|