Class: Courier::Models::ProfileUpdateParams::Patch

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/profile_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(op:, path:, value:) ⇒ Object



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/courier/models/profile_update_params.rb', line 21

class Patch < Courier::Internal::Type::BaseModel
  # @!attribute op
  #   The operation to perform.
  #
  #   @return [String]
  required :op, String

  # @!attribute path
  #   The JSON path specifying the part of the profile to operate on.
  #
  #   @return [String]
  required :path, String

  # @!attribute value
  #   The value for the operation.
  #
  #   @return [String]
  required :value, String

  # @!method initialize(op:, path:, value:)
  #   @param op [String] The operation to perform.
  #
  #   @param path [String] The JSON path specifying the part of the profile to operate on.
  #
  #   @param value [String] The value for the operation.
end

Instance Attribute Details

#opString

The operation to perform.



26
# File 'lib/courier/models/profile_update_params.rb', line 26

required :op, String

#pathString

The JSON path specifying the part of the profile to operate on.



32
# File 'lib/courier/models/profile_update_params.rb', line 32

required :path, String

#valueString

The value for the operation.



38
# File 'lib/courier/models/profile_update_params.rb', line 38

required :value, String