Class: Courier::Models::PutTenantTemplateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/put_tenant_template_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, version:, published_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::PutTenantTemplateResponse for more details.

Response from creating or updating a tenant notification template

Parameters:

  • id (String)

    The template ID

  • version (String)

    The version of the saved template

  • published_at (String, nil) (defaults to: nil)

    The timestamp when the template was published. Only present if the template was



# File 'lib/courier/models/put_tenant_template_response.rb', line 25

Instance Attribute Details

#idString

The template ID

Returns:

  • (String)


10
# File 'lib/courier/models/put_tenant_template_response.rb', line 10

required :id, String

#published_atString?

The timestamp when the template was published. Only present if the template was published as part of this request.

Returns:

  • (String, nil)


23
# File 'lib/courier/models/put_tenant_template_response.rb', line 23

optional :published_at, String, nil?: true

#versionString

The version of the saved template

Returns:

  • (String)


16
# File 'lib/courier/models/put_tenant_template_response.rb', line 16

required :version, String