Class: Courier::Models::SendToMsTeamsChannelID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::SendToMsTeamsChannelID
- Defined in:
- lib/courier/models/send_to_ms_teams_channel_id.rb,
sig/courier/models/send_to_ms_teams_channel_id.rbs
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(channel_id:, service_url: nil, tenant_id: nil) ⇒ Object
constructor
Sends directly to a Microsoft Teams channel by its Bot Framework ID.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channel_id:, service_url: nil, tenant_id: nil) ⇒ Object
Sends directly to a Microsoft Teams channel by its Bot Framework ID. Still
provide at least one of tenant_id or service_url — sends without either have
failed Bot Framework authentication in testing.
|
|
# File 'lib/courier/models/send_to_ms_teams_channel_id.rb', line 21
|
Instance Attribute Details
#channel_id ⇒ String
9 |
# File 'lib/courier/models/send_to_ms_teams_channel_id.rb', line 9 required :channel_id, String |
#service_url ⇒ String?
14 |
# File 'lib/courier/models/send_to_ms_teams_channel_id.rb', line 14 optional :service_url, String |
#tenant_id ⇒ String?
19 |
# File 'lib/courier/models/send_to_ms_teams_channel_id.rb', line 19 optional :tenant_id, String |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/courier/models/send_to_ms_teams_channel_id.rbs', line 23
def to_hash: -> {
|