Class: Courier::Models::UserProfile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/user_profile.rb,
sig/courier/models/user_profile.rbs

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address: nil, airship: nil, apn: nil, aws_sns: nil, birthdate: nil, custom: nil, discord: nil, email: nil, email_verified: nil, expo: nil, facebook_psid: nil, family_name: nil, firebase_token: nil, gender: nil, given_name: nil, intercom: nil, locale: nil, middle_name: nil, ms_teams: nil, name: nil, nickname: nil, phone_number: nil, phone_number_verified: nil, picture: nil, preferred_name: nil, profile: nil, slack: nil, sub: nil, updated_at: nil, website: nil, zoneinfo: nil) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::UserProfile for more details.

Parameters:



# File 'lib/courier/models/user_profile.rb', line 173

Instance Attribute Details

#addressCourier::Models::UserProfile::Address?

Parameters:

  • value (Courier::UserProfile::Address, nil)

Returns:



9
# File 'lib/courier/models/user_profile.rb', line 9

optional :address, -> { Courier::UserProfile::Address }, nil?: true

#airshipCourier::Models::AirshipProfile?

Parameters:

Returns:



14
# File 'lib/courier/models/user_profile.rb', line 14

optional :airship, -> { Courier::AirshipProfile }, nil?: true

#apnCourier::Models::Token, ...

Apple Push Notification device tokens. Supply either a single token or a tokens value. A bare string is rejected by the provider — the token must be wrapped in this object.

Parameters:

  • value (Courier::Models::apn, nil)

Returns:



22
# File 'lib/courier/models/user_profile.rb', line 22

optional :apn, union: -> { Courier::Apn }, nil?: true

#aws_snsCourier::Models::AwsSns?

Routes a push notification through the AWS SNS provider. The target ARN must be nested under aws_sns — a top-level target_arn on the profile is ignored by the provider.

Parameters:

Returns:



30
# File 'lib/courier/models/user_profile.rb', line 30

optional :aws_sns, -> { Courier::AwsSns }, nil?: true

#birthdateString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


35
# File 'lib/courier/models/user_profile.rb', line 35

optional :birthdate, String, nil?: true

#customHash{Symbol=>Object}?

A free form object. Due to a limitation of the API Explorer, you can only enter string key/values below, but this API accepts more complex object structures.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


42
# File 'lib/courier/models/user_profile.rb', line 42

optional :custom, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown], nil?: true

#discordCourier::Models::SendToChannel, ...

Parameters:

  • value (Courier::Models::discord, nil)

Returns:



47
# File 'lib/courier/models/user_profile.rb', line 47

optional :discord, union: -> { Courier::Discord }, nil?: true

#emailString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


52
# File 'lib/courier/models/user_profile.rb', line 52

optional :email, String, nil?: true

#email_verifiedBoolean?

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


57
# File 'lib/courier/models/user_profile.rb', line 57

optional :email_verified, Courier::Internal::Type::Boolean, nil?: true

#expoCourier::Models::Token, ...

Expo push tokens. Supply either a single token or a tokens value.

Parameters:

  • value (Courier::Models::expo, nil)

Returns:



63
# File 'lib/courier/models/user_profile.rb', line 63

optional :expo, union: -> { Courier::Expo }, nil?: true

#facebook_psidString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


68
# File 'lib/courier/models/user_profile.rb', line 68

optional :facebook_psid, String, api_name: :facebookPSID, nil?: true

#family_nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


73
# File 'lib/courier/models/user_profile.rb', line 73

optional :family_name, String, nil?: true

#firebase_tokenString, ...

Parameters:

  • value (Courier::Models::user_profile_firebase_token, nil)

Returns:

  • (String, Array<String>, nil)


78
79
80
81
# File 'lib/courier/models/user_profile.rb', line 78

optional :firebase_token,
union: -> { Courier::UserProfileFirebaseToken },
api_name: :firebaseToken,
nil?: true

#genderString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


86
# File 'lib/courier/models/user_profile.rb', line 86

optional :gender, String, nil?: true

#given_nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


91
# File 'lib/courier/models/user_profile.rb', line 91

optional :given_name, String, nil?: true

#intercomCourier::Models::Intercom?

Parameters:

Returns:



96
# File 'lib/courier/models/user_profile.rb', line 96

optional :intercom, -> { Courier::Intercom }, nil?: true

#localeString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


101
# File 'lib/courier/models/user_profile.rb', line 101

optional :locale, String, nil?: true

#middle_nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


106
# File 'lib/courier/models/user_profile.rb', line 106

optional :middle_name, String, nil?: true

#ms_teamsCourier::Models::SendToMsTeamsUserID, ...



111
# File 'lib/courier/models/user_profile.rb', line 111

optional :ms_teams, union: -> { Courier::MsTeams }, nil?: true

#nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


116
# File 'lib/courier/models/user_profile.rb', line 116

optional :name, String, nil?: true

#nicknameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


121
# File 'lib/courier/models/user_profile.rb', line 121

optional :nickname, String, nil?: true

#phone_numberString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


126
# File 'lib/courier/models/user_profile.rb', line 126

optional :phone_number, String, nil?: true

#phone_number_verifiedBoolean?

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


131
# File 'lib/courier/models/user_profile.rb', line 131

optional :phone_number_verified, Courier::Internal::Type::Boolean, nil?: true

#pictureString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


136
# File 'lib/courier/models/user_profile.rb', line 136

optional :picture, String, nil?: true

#preferred_nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


141
# File 'lib/courier/models/user_profile.rb', line 141

optional :preferred_name, String, nil?: true

#profileString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


146
# File 'lib/courier/models/user_profile.rb', line 146

optional :profile, String, nil?: true

#slackCourier::Models::SendToSlackChannel, ...

Parameters:

  • value (Courier::Models::slack, nil)

Returns:



151
# File 'lib/courier/models/user_profile.rb', line 151

optional :slack, union: -> { Courier::Slack }, nil?: true

#subString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


156
# File 'lib/courier/models/user_profile.rb', line 156

optional :sub, String, nil?: true

#updated_atString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


161
# File 'lib/courier/models/user_profile.rb', line 161

optional :updated_at, String, nil?: true

#websiteString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


166
# File 'lib/courier/models/user_profile.rb', line 166

optional :website, String, nil?: true

#zoneinfoString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


171
# File 'lib/courier/models/user_profile.rb', line 171

optional :zoneinfo, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


135
# File 'sig/courier/models/user_profile.rbs', line 135

def to_hash: -> {