Class: Courier::Models::UserRecipient

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/user_recipient.rb

Defined Under Namespace

Classes: Preferences

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id: nil, context: nil, data: nil, email: nil, list_id: nil, locale: nil, phone_number: nil, preferences: nil, tenant_id: nil, user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::UserRecipient for more details.



# File 'lib/courier/models/user_recipient.rb', line 65


Instance Attribute Details

#account_idString?

Deprecated - Use tenant_id instead.



10
# File 'lib/courier/models/user_recipient.rb', line 10

optional :account_id, String, nil?: true

#contextCourier::Models::MessageContext?

Context such as tenant_id to send the notification with.



16
# File 'lib/courier/models/user_recipient.rb', line 16

optional :context, -> { Courier::MessageContext }, nil?: true

#dataHash{Symbol=>Object}?



21
# File 'lib/courier/models/user_recipient.rb', line 21

optional :data, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown], nil?: true

#emailString?

The user’s email address.



27
# File 'lib/courier/models/user_recipient.rb', line 27

optional :email, String, nil?: true

#list_idString?

The id of the list to send the message to.



33
# File 'lib/courier/models/user_recipient.rb', line 33

optional :list_id, String, nil?: true

#localeString?

The user’s preferred ISO 639-1 language code.



39
# File 'lib/courier/models/user_recipient.rb', line 39

optional :locale, String, nil?: true

#phone_numberString?

The user’s phone number.



45
# File 'lib/courier/models/user_recipient.rb', line 45

optional :phone_number, String, nil?: true

#preferencesCourier::Models::UserRecipient::Preferences?



50
# File 'lib/courier/models/user_recipient.rb', line 50

optional :preferences, -> { Courier::UserRecipient::Preferences }, nil?: true

#tenant_idString?

The id of the tenant the user is associated with.



56
# File 'lib/courier/models/user_recipient.rb', line 56

optional :tenant_id, String, nil?: true

#user_idString?

The user’s unique identifier. Typically, this will match the user id of a user in your system.



63
# File 'lib/courier/models/user_recipient.rb', line 63

optional :user_id, String, nil?: true