Class: Courier::Models::Users::BulkPreferenceTopic

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/users/bulk_preference_topic.rb,
sig/courier/models/users/bulk_preference_topic.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(custom_routing:, has_custom_routing:, status:, topic_id:) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::Users::BulkPreferenceTopic for more details.

A single topic override echoed in a bulk preference response.

Parameters:



# File 'lib/courier/models/users/bulk_preference_topic.rb', line 29

Instance Attribute Details

#custom_routingArray<Symbol, Courier::Models::ChannelClassification>

Parameters:

  • value (::Array[Courier::Models::channel_classification])

Returns:



10
# File 'lib/courier/models/users/bulk_preference_topic.rb', line 10

required :custom_routing, -> { Courier::Internal::Type::ArrayOf[enum: Courier::ChannelClassification] }

#has_custom_routingBoolean

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


15
# File 'lib/courier/models/users/bulk_preference_topic.rb', line 15

required :has_custom_routing, Courier::Internal::Type::Boolean

#statusSymbol, Courier::Models::Users::BulkPreferenceTopic::Status

The applied subscription status. Echoes the requested value, so it is always OPTED_IN or OPTED_OUT.

Parameters:

  • value (Courier::Models::Users::BulkPreferenceTopic::status)

Returns:



22
# File 'lib/courier/models/users/bulk_preference_topic.rb', line 22

required :status, enum: -> { Courier::Users::BulkPreferenceTopic::Status }

#topic_idString

Parameters:

  • value (String)

Returns:

  • (String)


27
# File 'lib/courier/models/users/bulk_preference_topic.rb', line 27

required :topic_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


28
# File 'sig/courier/models/users/bulk_preference_topic.rbs', line 28

def to_hash: -> {