Class: Courier::Models::Users::PreferenceBulkReplaceParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/courier/models/users/preference_bulk_replace_params.rb,
sig/courier/models/users/preference_bulk_replace_params.rbs

Overview

See Also:

  • Courier::Resources::Users::Preferences#bulk_replace

Defined Under Namespace

Classes: Topic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



22
# File 'sig/courier/models/users/preference_bulk_replace_params.rbs', line 22

def initialize: (

Instance Attribute Details

#tenant_idString?

Replace the preferences of a user for this specific tenant context.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


29
# File 'lib/courier/models/users/preference_bulk_replace_params.rb', line 29

optional :tenant_id, String, nil?: true

#topicsArray<Courier::Models::Users::PreferenceBulkReplaceParams::Topic>

The complete set of topic overrides for the user. Up to 50 topics may be provided. Any existing override not listed here is reset to its topic default; an empty array resets every existing override.

Parameters:

  • value (::Array[Courier::Users::PreferenceBulkReplaceParams::Topic])

Returns:



22
23
# File 'lib/courier/models/users/preference_bulk_replace_params.rb', line 22

required :topics,
-> { Courier::Internal::Type::ArrayOf[Courier::Users::PreferenceBulkReplaceParams::Topic] }

#user_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/courier/models/users/preference_bulk_replace_params.rb', line 14

required :user_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


29
# File 'sig/courier/models/users/preference_bulk_replace_params.rbs', line 29

def to_hash: -> {