Class: Courier::Models::Users::PreferenceBulkReplaceResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::Users::PreferenceBulkReplaceResponse
- Defined in:
- lib/courier/models/users/preference_bulk_replace_response.rb,
sig/courier/models/users/preference_bulk_replace_response.rbs
Overview
Instance Attribute Summary collapse
-
#deleted ⇒ Array<String>
The ids of the overrides that were reset to their topic default.
-
#items ⇒ Array<Courier::Models::Users::BulkPreferenceTopic>
The complete resulting set of topic overrides for the user.
Instance Method Summary collapse
- #initialize(deleted:, items:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(deleted:, items:) ⇒ Object
|
|
# File 'lib/courier/models/users/preference_bulk_replace_response.rb', line 20
|
Instance Attribute Details
#deleted ⇒ Array<String>
The ids of the overrides that were reset to their topic default.
12 |
# File 'lib/courier/models/users/preference_bulk_replace_response.rb', line 12 required :deleted, Courier::Internal::Type::ArrayOf[String] |
#items ⇒ Array<Courier::Models::Users::BulkPreferenceTopic>
The complete resulting set of topic overrides for the user.
18 |
# File 'lib/courier/models/users/preference_bulk_replace_response.rb', line 18 required :items, -> { Courier::Internal::Type::ArrayOf[Courier::Users::BulkPreferenceTopic] } |
Instance Method Details
#to_hash ⇒ {
20 |
# File 'sig/courier/models/users/preference_bulk_replace_response.rbs', line 20
def to_hash: -> {
|