Class: Courier::Models::Users::TokenAddSingleParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::Users::TokenAddSingleParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/courier/models/users/token_add_single_params.rb,
sig/courier/models/users/token_add_single_params.rbs
Overview
Defined Under Namespace
Modules: ExpiryDate, ProviderKey Classes: Device, Tracking
Instance Attribute Summary collapse
-
#device ⇒ Courier::Models::Users::TokenAddSingleParams::Device?
Information about the device the token came from.
-
#expiry_date ⇒ String, ...
When the token expires.
-
#properties ⇒ Object?
Properties about the token.
- #provider_key ⇒ Symbol, Courier::Models::Users::TokenAddSingleParams::ProviderKey
- #token ⇒ String
-
#tracking ⇒ Courier::Models::Users::TokenAddSingleParams::Tracking?
Tracking information about the device the token came from.
- #user_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ad_id: nil, app_id: nil, device_id: nil, manufacturer: nil, model: nil, platform: nil) ⇒ Object
constructor
Information about the device the token came from.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ad_id: nil, app_id: nil, device_id: nil, manufacturer: nil, model: nil, platform: nil) ⇒ Object
Information about the device the token came from.
|
|
# File 'lib/courier/models/users/token_add_single_params.rb', line 124
|
Instance Attribute Details
#device ⇒ Courier::Models::Users::TokenAddSingleParams::Device?
Information about the device the token came from.
30 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 30 optional :device, -> { Courier::Users::TokenAddSingleParams::Device }, nil?: true |
#expiry_date ⇒ String, ...
When the token expires. Accepts a date, or the boolean false to disable
expiration entirely. ISO 8601 is recommended (for example
2026-10-25T00:00:00.000Z). A value that cannot be parsed as a date is
rejected; it is not treated as "no expiration" and does not fall back to the
default. true is not a supported value. Omit the field to use the default,
which expires a token that has not been re-registered for 60 days.
41 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 41 optional :expiry_date, union: -> { Courier::Users::TokenAddSingleParams::ExpiryDate }, nil?: true |
#properties ⇒ Object?
Properties about the token.
47 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 47 optional :properties, Courier::Internal::Type::Unknown |
#provider_key ⇒ Symbol, Courier::Models::Users::TokenAddSingleParams::ProviderKey
24 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 24 required :provider_key, enum: -> { Courier::Users::TokenAddSingleParams::ProviderKey } |
#token ⇒ String
19 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 19 required :token, String |
#tracking ⇒ Courier::Models::Users::TokenAddSingleParams::Tracking?
Tracking information about the device the token came from.
53 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 53 optional :tracking, -> { Courier::Users::TokenAddSingleParams::Tracking }, nil?: true |
#user_id ⇒ String
14 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 14 required :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/courier/models/users/token_add_single_params.rb', line 83
|
.variants ⇒ Array(String, Boolean)
|
|
# File 'lib/courier/models/users/token_add_single_params.rb', line 153
|
Instance Method Details
#to_hash ⇒ {
47 |
# File 'sig/courier/models/users/token_add_single_params.rbs', line 47 def to_hash: -> { |