Class: Courier::Models::Users::TokenAddSingleParams::Device

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/users/token_add_single_params.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Courier::Internal::Type::BaseModel

Instance Attribute Details

#ad_idString?

Id of the advertising identifier

Returns:

  • (String, nil)


88
# File 'lib/courier/models/users/token_add_single_params.rb', line 88

optional :ad_id, String, nil?: true

#app_idString?

Id of the application the token is used for

Returns:

  • (String, nil)


94
# File 'lib/courier/models/users/token_add_single_params.rb', line 94

optional :app_id, String, nil?: true

#device_idString?

Id of the device the token is associated with

Returns:

  • (String, nil)


100
# File 'lib/courier/models/users/token_add_single_params.rb', line 100

optional :device_id, String, nil?: true

#manufacturerString?

The device manufacturer

Returns:

  • (String, nil)


106
# File 'lib/courier/models/users/token_add_single_params.rb', line 106

optional :manufacturer, String, nil?: true

#modelString?

The device model

Returns:

  • (String, nil)


112
# File 'lib/courier/models/users/token_add_single_params.rb', line 112

optional :model, String, nil?: true

#platformString?

The device platform i.e. android, ios, web

Returns:

  • (String, nil)


118
# File 'lib/courier/models/users/token_add_single_params.rb', line 118

optional :platform, String, nil?: true