Class: Courier::Models::Users::TokenAddSingleParams::Tracking
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::Users::TokenAddSingleParams::Tracking
- Defined in:
- lib/courier/models/users/token_add_single_params.rb
Instance Attribute Summary collapse
-
#ip ⇒ String?
The IP address of the device.
-
#lat ⇒ String?
The latitude of the device.
-
#long ⇒ String?
The longitude of the device.
-
#os_version ⇒ String?
The operating system version.
Instance Method Summary collapse
-
#initialize(ip: nil, lat: nil, long: nil, os_version: nil) ⇒ Object
constructor
Tracking information about the device the token came from.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip: nil, lat: nil, long: nil, os_version: nil) ⇒ Object
Tracking information about the device the token came from.
|
|
# File 'lib/courier/models/users/token_add_single_params.rb', line 174
|
Instance Attribute Details
#ip ⇒ String?
The IP address of the device
154 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 154 optional :ip, String, nil?: true |
#lat ⇒ String?
The latitude of the device
160 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 160 optional :lat, String, nil?: true |
#long ⇒ String?
The longitude of the device
166 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 166 optional :long, String, nil?: true |
#os_version ⇒ String?
The operating system version
172 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 172 optional :os_version, String, nil?: true |