Class: Courier::Models::Users::UserToken

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/users/user_token.rb

Direct Known Subclasses

TokenAddSingleParams, TokenRetrieveResponse

Defined Under Namespace

Modules: ExpiryDate, ProviderKey Classes: Device, Tracking

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ad_id: nil, app_id: nil, device_id: nil, manufacturer: nil, model: nil, platform: nil) ⇒ Object

Information about the device the token came from.

Parameters:

  • ad_id (String, nil) (defaults to: nil)

    Id of the advertising identifier

  • app_id (String, nil) (defaults to: nil)

    Id of the application the token is used for

  • device_id (String, nil) (defaults to: nil)

    Id of the device the token is associated with

  • manufacturer (String, nil) (defaults to: nil)

    The device manufacturer

  • model (String, nil) (defaults to: nil)

    The device model

  • platform (String, nil) (defaults to: nil)

    The device platform i.e. android, ios, web



# File 'lib/courier/models/users/user_token.rb', line 43

Instance Attribute Details

#deviceCourier::Models::Users::UserToken::Device?

Information about the device the token came from.



22
# File 'lib/courier/models/users/user_token.rb', line 22

optional :device, -> { Courier::Users::UserToken::Device }, nil?: true

#expiry_dateString, ...

ISO 8601 formatted date the token expires. Defaults to 2 months. Set to false to disable expiration.

Returns:

  • (String, Boolean, nil)


29
# File 'lib/courier/models/users/user_token.rb', line 29

optional :expiry_date, union: -> { Courier::Users::UserToken::ExpiryDate }, nil?: true

#propertiesObject?

Properties about the token.

Returns:

  • (Object, nil)


35
# File 'lib/courier/models/users/user_token.rb', line 35

optional :properties, Courier::Internal::Type::Unknown

#provider_keySymbol, Courier::Models::Users::UserToken::ProviderKey



16
# File 'lib/courier/models/users/user_token.rb', line 16

required :provider_key, enum: -> { Courier::Users::UserToken::ProviderKey }

#tokenString

Full body of the token. Must match token in URL path parameter.

Returns:

  • (String)


11
# File 'lib/courier/models/users/user_token.rb', line 11

required :token, String

#trackingCourier::Models::Users::UserToken::Tracking?

Tracking information about the device the token came from.



41
# File 'lib/courier/models/users/user_token.rb', line 41

optional :tracking, -> { Courier::Users::UserToken::Tracking }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/courier/models/users/user_token.rb', line 68

.variantsArray(String, Boolean)

Returns:

  • (Array(String, Boolean))


# File 'lib/courier/models/users/user_token.rb', line 137