Class: Courier::Resources::Digests

Inherits:
Object
  • Object
show all
Defined in:
lib/courier/resources/digests.rb,
lib/courier/resources/digests/schedules.rb,
sig/courier/resources/digests.rbs,
sig/courier/resources/digests/schedules.rbs

Defined Under Namespace

Classes: Schedules

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Digests

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Digests.

Parameters:



14
15
16
17
# File 'lib/courier/resources/digests.rb', line 14

def initialize(client:)
  @client = client
  @schedules = Courier::Resources::Digests::Schedules.new(client: client)
end

Instance Attribute Details

#schedulesCourier::Resources::Digests::Schedules (readonly)

Inspect what has accumulated in a digest schedule and release a digest ahead of its next scheduled delivery.



9
10
11
# File 'lib/courier/resources/digests.rb', line 9

def schedules
  @schedules
end