Class: Trycourier::Models::InboundBulkMessage::InboundBulkContentMessage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/trycourier/models/inbound_bulk_message.rb

Defined Under Namespace

Modules: Content

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content: , brand: nil, data: nil, event: nil, locale: nil, override: nil) ⇒ Object

Parameters:

  • content (Trycourier::Models::ElementalContentSugar, Trycourier::Models::ElementalContent) (defaults to: )

    Syntactic sugar to provide a fast shorthand for Courier Elemental Blocks.

  • brand (String, nil) (defaults to: nil)
  • data (Hash{Symbol=>Object}, nil) (defaults to: nil)
  • event (String, nil) (defaults to: nil)
  • locale (Hash{Symbol=>Hash{Symbol=>Object}}, nil) (defaults to: nil)
  • override (Hash{Symbol=>Object}, nil) (defaults to: nil)


# File 'lib/trycourier/models/inbound_bulk_message.rb', line 92

Instance Attribute Details

#brandString?

Returns:

  • (String, nil)


66
# File 'lib/trycourier/models/inbound_bulk_message.rb', line 66

optional :brand, String, nil?: true

#contentTrycourier::Models::ElementalContentSugar, Trycourier::Models::ElementalContent

Syntactic sugar to provide a fast shorthand for Courier Elemental Blocks.



61
# File 'lib/trycourier/models/inbound_bulk_message.rb', line 61

required :content, union: -> { Trycourier::InboundBulkMessage::InboundBulkContentMessage::Content }

#dataHash{Symbol=>Object}?

Returns:

  • (Hash{Symbol=>Object}, nil)


71
# File 'lib/trycourier/models/inbound_bulk_message.rb', line 71

optional :data, Trycourier::Internal::Type::HashOf[Trycourier::Internal::Type::Unknown], nil?: true

#eventString?

Returns:

  • (String, nil)


76
# File 'lib/trycourier/models/inbound_bulk_message.rb', line 76

optional :event, String, nil?: true

#localeHash{Symbol=>Hash{Symbol=>Object}}?

Returns:

  • (Hash{Symbol=>Hash{Symbol=>Object}}, nil)


81
82
83
# File 'lib/trycourier/models/inbound_bulk_message.rb', line 81

optional :locale,
Trycourier::Internal::Type::HashOf[Trycourier::Internal::Type::HashOf[Trycourier::Internal::Type::Unknown]],
nil?: true

#overrideHash{Symbol=>Object}?

Returns:

  • (Hash{Symbol=>Object}, nil)


88
89
90
# File 'lib/trycourier/models/inbound_bulk_message.rb', line 88

optional :override,
Trycourier::Internal::Type::HashOf[Trycourier::Internal::Type::Unknown],
nil?: true