Class: Trycourier::Models::MessageDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/trycourier/models/message_details.rb

Direct Known Subclasses

MessageRetrieveResponse

Defined Under Namespace

Modules: Reason, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , clicked: , delivered: , enqueued: , event: , notification: , opened: , recipient: , sent: , status: , error: nil, reason: nil) ⇒ Object

Some parameter documentations has been truncated, see Trycourier::Models::MessageDetails for more details.

Parameters:

  • id (String) (defaults to: )

    A unique identifier associated with the message you wish to retrieve (results fr

  • clicked (Integer) (defaults to: )

    A UTC timestamp at which the recipient clicked on a tracked link for the first t

  • delivered (Integer) (defaults to: )

    A UTC timestamp at which the Integration provider delivered the message. Stored

  • enqueued (Integer) (defaults to: )

    A UTC timestamp at which Courier received the message request. Stored as a milli

  • event (String) (defaults to: )

    A unique identifier associated with the event of the delivered message.

  • notification (String) (defaults to: )

    A unique identifier associated with the notification of the delivered message.

  • opened (Integer) (defaults to: )

    A UTC timestamp at which the recipient opened a message for the first time. Stor

  • recipient (String) (defaults to: )

    A unique identifier associated with the recipient of the delivered message.

  • sent (Integer) (defaults to: )

    A UTC timestamp at which Courier passed the message to the Integration provider.

  • status (Symbol, Trycourier::Models::MessageDetails::Status) (defaults to: )

    The current status of the message.

  • error (String, nil) (defaults to: nil)

    A message describing the error that occurred.

  • reason (Symbol, Trycourier::Models::MessageDetails::Reason, nil) (defaults to: nil)

    The reason for the current status of the message.



# File 'lib/trycourier/models/message_details.rb', line 84

Instance Attribute Details

#clickedInteger

A UTC timestamp at which the recipient clicked on a tracked link for the first time. Stored as a millisecond representation of the Unix epoch.

Returns:

  • (Integer)


18
# File 'lib/trycourier/models/message_details.rb', line 18

required :clicked, Integer

#deliveredInteger

A UTC timestamp at which the Integration provider delivered the message. Stored as a millisecond representation of the Unix epoch.

Returns:

  • (Integer)


25
# File 'lib/trycourier/models/message_details.rb', line 25

required :delivered, Integer

#enqueuedInteger

A UTC timestamp at which Courier received the message request. Stored as a millisecond representation of the Unix epoch.

Returns:

  • (Integer)


32
# File 'lib/trycourier/models/message_details.rb', line 32

required :enqueued, Integer

#errorString?

A message describing the error that occurred.

Returns:

  • (String, nil)


76
# File 'lib/trycourier/models/message_details.rb', line 76

optional :error, String, nil?: true

#eventString

A unique identifier associated with the event of the delivered message.

Returns:

  • (String)


38
# File 'lib/trycourier/models/message_details.rb', line 38

required :event, String

#idString

A unique identifier associated with the message you wish to retrieve (results from a send).

Returns:

  • (String)


11
# File 'lib/trycourier/models/message_details.rb', line 11

required :id, String

#notificationString

A unique identifier associated with the notification of the delivered message.

Returns:

  • (String)


44
# File 'lib/trycourier/models/message_details.rb', line 44

required :notification, String

#openedInteger

A UTC timestamp at which the recipient opened a message for the first time. Stored as a millisecond representation of the Unix epoch.

Returns:

  • (Integer)


51
# File 'lib/trycourier/models/message_details.rb', line 51

required :opened, Integer

#reasonSymbol, ...

The reason for the current status of the message.



82
# File 'lib/trycourier/models/message_details.rb', line 82

optional :reason, enum: -> { Trycourier::MessageDetails::Reason }, nil?: true

#recipientString

A unique identifier associated with the recipient of the delivered message.

Returns:

  • (String)


57
# File 'lib/trycourier/models/message_details.rb', line 57

required :recipient, String

#sentInteger

A UTC timestamp at which Courier passed the message to the Integration provider. Stored as a millisecond representation of the Unix epoch.

Returns:

  • (Integer)


64
# File 'lib/trycourier/models/message_details.rb', line 64

required :sent, Integer

#statusSymbol, Trycourier::Models::MessageDetails::Status

The current status of the message.



70
# File 'lib/trycourier/models/message_details.rb', line 70

required :status, enum: -> { Trycourier::MessageDetails::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/trycourier/models/message_details.rb', line 134