Class: Trycourier::Models::Tenant
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Trycourier::Models::Tenant
- Defined in:
- lib/trycourier/models/tenant.rb
Instance Attribute Summary collapse
-
#brand_id ⇒ String?
Brand to be used for the account when one is not specified by the send call.
-
#default_preferences ⇒ Trycourier::Models::DefaultPreferences?
Defines the preferences used for the account when the user hasn’t specified their own.
-
#id ⇒ String
Id of the tenant.
-
#name ⇒ String
Name of the tenant.
-
#parent_tenant_id ⇒ String?
Tenant’s parent id (if any).
-
#properties ⇒ Hash{Symbol=>Object}?
Arbitrary properties accessible to a template.
-
#user_profile ⇒ Hash{Symbol=>Object}?
A user profile object merged with user profile on send.
Instance Method Summary collapse
-
#initialize(id: , name: , brand_id: nil, default_preferences: nil, parent_tenant_id: nil, properties: nil, user_profile: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Tenant for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , name: , brand_id: nil, default_preferences: nil, parent_tenant_id: nil, properties: nil, user_profile: nil) ⇒ Object
Some parameter documentations has been truncated, see Trycourier::Models::Tenant for more details.
|
|
# File 'lib/trycourier/models/tenant.rb', line 53
|
Instance Attribute Details
#brand_id ⇒ String?
Brand to be used for the account when one is not specified by the send call.
22 |
# File 'lib/trycourier/models/tenant.rb', line 22 optional :brand_id, String, nil?: true |
#default_preferences ⇒ Trycourier::Models::DefaultPreferences?
Defines the preferences used for the account when the user hasn’t specified their own.
29 |
# File 'lib/trycourier/models/tenant.rb', line 29 optional :default_preferences, -> { Trycourier::DefaultPreferences }, nil?: true |
#id ⇒ String
Id of the tenant.
10 |
# File 'lib/trycourier/models/tenant.rb', line 10 required :id, String |
#name ⇒ String
Name of the tenant.
16 |
# File 'lib/trycourier/models/tenant.rb', line 16 required :name, String |
#parent_tenant_id ⇒ String?
Tenant’s parent id (if any).
35 |
# File 'lib/trycourier/models/tenant.rb', line 35 optional :parent_tenant_id, String, nil?: true |
#properties ⇒ Hash{Symbol=>Object}?
Arbitrary properties accessible to a template.
41 42 43 |
# File 'lib/trycourier/models/tenant.rb', line 41 optional :properties, Trycourier::Internal::Type::HashOf[Trycourier::Internal::Type::Unknown], nil?: true |
#user_profile ⇒ Hash{Symbol=>Object}?
A user profile object merged with user profile on send.
49 50 51 |
# File 'lib/trycourier/models/tenant.rb', line 49 optional :user_profile, Trycourier::Internal::Type::HashOf[Trycourier::Internal::Type::Unknown], nil?: true |