Class: Trycourier::Models::UserToken

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/trycourier/models/user_token.rb

Defined Under Namespace

Modules: ExpiryDate, ProviderKey Classes: Device, Tracking

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ad_id: nil, app_id: nil, device_id: nil, manufacturer: nil, model: nil, platform: nil) ⇒ Object

Information about the device the token is associated with.

Parameters:

  • ad_id (String, nil) (defaults to: nil)

    Id of the advertising identifier

  • app_id (String, nil) (defaults to: nil)

    Id of the application the token is used for

  • device_id (String, nil) (defaults to: nil)

    Id of the device the token is associated with

  • manufacturer (String, nil) (defaults to: nil)

    The device manufacturer

  • model (String, nil) (defaults to: nil)

    The device model

  • platform (String, nil) (defaults to: nil)

    The device platform i.e. android, ios, web



# File 'lib/trycourier/models/user_token.rb', line 42

Instance Attribute Details

#deviceTrycourier::Models::UserToken::Device?

Information about the device the token is associated with.



21
# File 'lib/trycourier/models/user_token.rb', line 21

optional :device, -> { Trycourier::UserToken::Device }, nil?: true

#expiry_dateString, ...

ISO 8601 formatted date the token expires. Defaults to 2 months. Set to false to disable expiration.

Returns:

  • (String, Boolean, nil)


28
# File 'lib/trycourier/models/user_token.rb', line 28

optional :expiry_date, union: -> { Trycourier::UserToken::ExpiryDate }, nil?: true

#propertiesObject?

Properties sent to the provider along with the token

Returns:

  • (Object, nil)


34
# File 'lib/trycourier/models/user_token.rb', line 34

optional :properties, Trycourier::Internal::Type::Unknown

#provider_keySymbol, Trycourier::Models::UserToken::ProviderKey



9
# File 'lib/trycourier/models/user_token.rb', line 9

required :provider_key, enum: -> { Trycourier::UserToken::ProviderKey }

#tokenString?

Full body of the token. Must match token in URL.

Returns:

  • (String, nil)


15
# File 'lib/trycourier/models/user_token.rb', line 15

optional :token, String, nil?: true

#trackingTrycourier::Models::UserToken::Tracking?

Information about the device the token is associated with.



40
# File 'lib/trycourier/models/user_token.rb', line 40

optional :tracking, -> { Trycourier::UserToken::Tracking }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/trycourier/models/user_token.rb', line 67

.variantsArray(String, Boolean)

Returns:

  • (Array(String, Boolean))


# File 'lib/trycourier/models/user_token.rb', line 136