Class: Trycourier::Models::UserToken::Device
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Trycourier::Models::UserToken::Device
- Defined in:
- lib/trycourier/models/user_token.rb
Overview
Instance Attribute Summary collapse
-
#ad_id ⇒ String?
Id of the advertising identifier.
-
#app_id ⇒ String?
Id of the application the token is used for.
-
#device_id ⇒ String?
Id of the device the token is associated with.
-
#manufacturer ⇒ String?
The device manufacturer.
-
#model ⇒ String?
The device model.
-
#platform ⇒ String?
The device platform i.e.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Trycourier::Internal::Type::BaseModel
Instance Attribute Details
#ad_id ⇒ String?
Id of the advertising identifier
77 |
# File 'lib/trycourier/models/user_token.rb', line 77 optional :ad_id, String, nil?: true |
#app_id ⇒ String?
Id of the application the token is used for
83 |
# File 'lib/trycourier/models/user_token.rb', line 83 optional :app_id, String, nil?: true |
#device_id ⇒ String?
Id of the device the token is associated with
89 |
# File 'lib/trycourier/models/user_token.rb', line 89 optional :device_id, String, nil?: true |
#manufacturer ⇒ String?
The device manufacturer
95 |
# File 'lib/trycourier/models/user_token.rb', line 95 optional :manufacturer, String, nil?: true |
#model ⇒ String?
The device model
101 |
# File 'lib/trycourier/models/user_token.rb', line 101 optional :model, String, nil?: true |
#platform ⇒ String?
The device platform i.e. android, ios, web
107 |
# File 'lib/trycourier/models/user_token.rb', line 107 optional :platform, String, nil?: true |