Class: Courier::Models::AwsSns
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::AwsSns
- Defined in:
- lib/courier/models/aws_sns.rb,
sig/courier/models/aws_sns.rbs
Instance Attribute Summary collapse
-
#target_arn ⇒ String
The ARN of the SNS platform endpoint, topic, or application to publish to.
Instance Method Summary collapse
-
#initialize(target_arn:) ⇒ AwsSns
constructor
Routes a push notification through the AWS SNS provider.
- #to_hash ⇒ { target_arn: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(target_arn:) ⇒ AwsSns
Routes a push notification through the AWS SNS provider. The target ARN must be
nested under aws_sns — a top-level target_arn on the profile is ignored by
the provider.
|
|
# File 'lib/courier/models/aws_sns.rb', line 12
|
Instance Attribute Details
#target_arn ⇒ String
The ARN of the SNS platform endpoint, topic, or application to publish to.
10 |
# File 'lib/courier/models/aws_sns.rb', line 10 required :target_arn, String |
Instance Method Details
#to_hash ⇒ { target_arn: String }
10 |
# File 'sig/courier/models/aws_sns.rbs', line 10
def to_hash: -> { target_arn: String }
|