Class: Courier::Models::Broadcast
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::Broadcast
- Defined in:
- lib/courier/models/broadcast.rb,
sig/courier/models/broadcast.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#archived_at ⇒ String?
ISO 8601 timestamp when the broadcast was archived, if archived.
-
#archived_by ⇒ String?
Actor that archived the broadcast, if archived.
-
#channel ⇒ Symbol, Courier::Models::Broadcast::Channel
The broadcast's delivery channel.
-
#created_at ⇒ String
ISO 8601 timestamp when the broadcast was created.
-
#created_by ⇒ String
Actor that created the broadcast.
-
#id ⇒ String
The broadcast ID (bst_ prefix).
-
#name ⇒ String
Human-readable name.
-
#schedule ⇒ Courier::Models::BroadcastSchedule?
The delivery schedule and recipient targeting for a broadcast.
-
#status ⇒ Symbol, Courier::Models::Broadcast::Status
Lifecycle status of the broadcast.
-
#updated_at ⇒ String
ISO 8601 timestamp of the last update.
-
#updated_by ⇒ String
Actor that last updated the broadcast.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, channel:, created_at:, created_by:, name:, status:, updated_at:, updated_by:, archived_at: nil, archived_by: nil, schedule: nil) ⇒ Object
constructor
A broadcast — a single-channel message delivered to a known set of recipients (a list or audience).
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, channel:, created_at:, created_by:, name:, status:, updated_at:, updated_by:, archived_at: nil, archived_by: nil, schedule: nil) ⇒ Object
A broadcast — a single-channel message delivered to a known set of recipients (a list or audience).
|
|
# File 'lib/courier/models/broadcast.rb', line 73
|
Instance Attribute Details
#archived_at ⇒ String?
ISO 8601 timestamp when the broadcast was archived, if archived.
59 |
# File 'lib/courier/models/broadcast.rb', line 59 optional :archived_at, String, nil?: true |
#archived_by ⇒ String?
Actor that archived the broadcast, if archived.
65 |
# File 'lib/courier/models/broadcast.rb', line 65 optional :archived_by, String, nil?: true |
#channel ⇒ Symbol, Courier::Models::Broadcast::Channel
The broadcast's delivery channel.
17 |
# File 'lib/courier/models/broadcast.rb', line 17 required :channel, enum: -> { Courier::Broadcast::Channel } |
#created_at ⇒ String
ISO 8601 timestamp when the broadcast was created.
23 |
# File 'lib/courier/models/broadcast.rb', line 23 required :created_at, String |
#created_by ⇒ String
Actor that created the broadcast.
29 |
# File 'lib/courier/models/broadcast.rb', line 29 required :created_by, String |
#id ⇒ String
The broadcast ID (bst_ prefix).
11 |
# File 'lib/courier/models/broadcast.rb', line 11 required :id, String |
#name ⇒ String
Human-readable name.
35 |
# File 'lib/courier/models/broadcast.rb', line 35 required :name, String |
#schedule ⇒ Courier::Models::BroadcastSchedule?
The delivery schedule and recipient targeting for a broadcast.
71 |
# File 'lib/courier/models/broadcast.rb', line 71 optional :schedule, -> { Courier::BroadcastSchedule }, nil?: true |
#status ⇒ Symbol, Courier::Models::Broadcast::Status
Lifecycle status of the broadcast.
41 |
# File 'lib/courier/models/broadcast.rb', line 41 required :status, enum: -> { Courier::Broadcast::Status } |
#updated_at ⇒ String
ISO 8601 timestamp of the last update.
47 |
# File 'lib/courier/models/broadcast.rb', line 47 required :updated_at, String |
#updated_by ⇒ String
Actor that last updated the broadcast.
53 |
# File 'lib/courier/models/broadcast.rb', line 53 required :updated_by, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/courier/models/broadcast.rb', line 112
|
Instance Method Details
#to_hash ⇒ {
55 |
# File 'sig/courier/models/broadcast.rbs', line 55
def to_hash: -> {
|