Class: Courier::Models::DigestInstance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::DigestInstance
- Defined in:
- lib/courier/models/digest_instance.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#categories ⇒ Array<Courier::Models::DigestCategory>?
The categories configured for the digest.
-
#category_key_counts ⇒ Hash{Symbol=>Integer}?
A map of category key to the number of events received for that category.
-
#created_at ⇒ String?
An ISO 8601 timestamp of when the digest instance was created.
-
#digest_instance_id ⇒ String
A unique identifier for the digest instance.
-
#disabled ⇒ Boolean?
Whether the digest instance has been disabled.
-
#event_count ⇒ Integer
The total number of events received for this instance.
-
#status ⇒ Symbol, Courier::Models::DigestInstance::Status
The status of the digest instance.
-
#tenant_id ⇒ String?
The ID of the tenant this digest instance belongs to, if any.
-
#user_id ⇒ String
The ID of the user this digest instance belongs to.
Instance Method Summary collapse
-
#initialize(digest_instance_id:, event_count:, status:, user_id:, categories: nil, category_key_counts: nil, created_at: nil, disabled: nil, tenant_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DigestInstance for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(digest_instance_id:, event_count:, status:, user_id:, categories: nil, category_key_counts: nil, created_at: nil, disabled: nil, tenant_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::DigestInstance for more details.
|
|
# File 'lib/courier/models/digest_instance.rb', line 61
|
Instance Attribute Details
#categories ⇒ Array<Courier::Models::DigestCategory>?
The categories configured for the digest.
35 |
# File 'lib/courier/models/digest_instance.rb', line 35 optional :categories, -> { Courier::Internal::Type::ArrayOf[Courier::DigestCategory] } |
#category_key_counts ⇒ Hash{Symbol=>Integer}?
A map of category key to the number of events received for that category.
41 |
# File 'lib/courier/models/digest_instance.rb', line 41 optional :category_key_counts, Courier::Internal::Type::HashOf[Integer] |
#created_at ⇒ String?
An ISO 8601 timestamp of when the digest instance was created.
47 |
# File 'lib/courier/models/digest_instance.rb', line 47 optional :created_at, String |
#digest_instance_id ⇒ String
A unique identifier for the digest instance.
10 |
# File 'lib/courier/models/digest_instance.rb', line 10 required :digest_instance_id, String |
#disabled ⇒ Boolean?
Whether the digest instance has been disabled.
53 |
# File 'lib/courier/models/digest_instance.rb', line 53 optional :disabled, Courier::Internal::Type::Boolean |
#event_count ⇒ Integer
The total number of events received for this instance.
16 |
# File 'lib/courier/models/digest_instance.rb', line 16 required :event_count, Integer |
#status ⇒ Symbol, Courier::Models::DigestInstance::Status
The status of the digest instance. ‘IN_PROGRESS` instances are still accumulating events; `COMPLETED` instances have been released.
23 |
# File 'lib/courier/models/digest_instance.rb', line 23 required :status, enum: -> { Courier::DigestInstance::Status } |
#tenant_id ⇒ String?
The ID of the tenant this digest instance belongs to, if any.
59 |
# File 'lib/courier/models/digest_instance.rb', line 59 optional :tenant_id, String, nil?: true |
#user_id ⇒ String
The ID of the user this digest instance belongs to.
29 |
# File 'lib/courier/models/digest_instance.rb', line 29 required :user_id, String |