Class: Courier::Models::ElementalQuoteNode
- Inherits:
-
ElementalBaseNode
- Object
- Internal::Type::BaseModel
- ElementalBaseNode
- Courier::Models::ElementalQuoteNode
- Defined in:
- lib/courier/models/elemental_quote_node.rb,
sig/courier/models/elemental_quote_node.rbs
Direct Known Subclasses
Instance Attribute Summary collapse
-
#align ⇒ Symbol, ...
Alignment of the quote.
-
#border_color ⇒ String?
CSS border color property.
-
#content ⇒ String
The text value of the quote.
-
#font_size ⇒ String?
CSS px font size for this quote block, e.g.
-
#line_height ⇒ String?
CSS line height for this quote block, as a px value or a unitless multiplier, e.g.
-
#locales ⇒ Hash{Symbol=>Courier::Models::LocaleItem}?
Region specific content.
- #text_style ⇒ Symbol, ...
Attributes inherited from ElementalBaseNode
Instance Method Summary collapse
-
#initialize(content:, align: nil, border_color: nil, font_size: nil, line_height: nil, locales: nil, text_style: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ElementalQuoteNode for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content:, align: nil, border_color: nil, font_size: nil, line_height: nil, locales: nil, text_style: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::ElementalQuoteNode for more details.
Renders a quote block.
|
|
# File 'lib/courier/models/elemental_quote_node.rb', line 51
|
Instance Attribute Details
#align ⇒ Symbol, ...
Alignment of the quote.
16 |
# File 'lib/courier/models/elemental_quote_node.rb', line 16 optional :align, enum: -> { Courier::Alignment }, nil?: true |
#border_color ⇒ String?
CSS border color property. For example, #fff
22 |
# File 'lib/courier/models/elemental_quote_node.rb', line 22 optional :border_color, String, nil?: true |
#content ⇒ String
The text value of the quote.
10 |
# File 'lib/courier/models/elemental_quote_node.rb', line 10 required :content, String |
#font_size ⇒ String?
CSS px font size for this quote block, e.g. 16px. Overrides the size of the
text_style preset. Email only.
29 |
# File 'lib/courier/models/elemental_quote_node.rb', line 29 optional :font_size, String, nil?: true |
#line_height ⇒ String?
CSS line height for this quote block, as a px value or a unitless multiplier,
e.g. 24px or 1.5. Email only.
36 |
# File 'lib/courier/models/elemental_quote_node.rb', line 36 optional :line_height, String, nil?: true |
#locales ⇒ Hash{Symbol=>Courier::Models::LocaleItem}?
Region specific content. See locales docs for more details.
44 |
# File 'lib/courier/models/elemental_quote_node.rb', line 44 optional :locales, -> { Courier::Internal::Type::HashOf[Courier::LocaleItem] }, nil?: true |
#text_style ⇒ Symbol, ...
49 |
# File 'lib/courier/models/elemental_quote_node.rb', line 49 optional :text_style, enum: -> { Courier::TextStyle } |
Instance Method Details
#to_hash ⇒ {
55 |
# File 'sig/courier/models/elemental_quote_node.rbs', line 55
def to_hash: -> {
|