Class: Courier::Models::JourneyExperiment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::JourneyExperiment
- Defined in:
- lib/courier/models/journey_experiment.rb,
sig/courier/models/journey_experiment.rbs
Instance Attribute Summary collapse
-
#bucketing_key ⇒ String
The value used to deterministically assign a recipient to a variant.
-
#id ⇒ String?
Unique experiment id (prefixed
exp_). -
#name ⇒ String?
Optional display name for the experiment.
-
#variants ⇒ Array<Courier::Models::JourneyExperimentVariant>
Between 2 and 10 weighted template variants.
Instance Method Summary collapse
-
#initialize(bucketing_key:, variants:, id: nil, name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see JourneyExperiment for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bucketing_key:, variants:, id: nil, name: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::JourneyExperiment for more details.
A/B experiment config for a send node. The recipient is deterministically
bucketed by bucketingKey and routed to one of the variants in proportion to
its weight. Present on a send node INSTEAD OF message.template.
|
|
# File 'lib/courier/models/journey_experiment.rb', line 32
|
Instance Attribute Details
#bucketing_key ⇒ String
The value used to deterministically assign a recipient to a variant. Must be non-empty with no leading or trailing whitespace.
11 |
# File 'lib/courier/models/journey_experiment.rb', line 11 required :bucketing_key, String, api_name: :bucketingKey |
#id ⇒ String?
Unique experiment id (prefixed exp_). Omit to have one generated
automatically; when supplied it must be a valid exp_ id.
24 |
# File 'lib/courier/models/journey_experiment.rb', line 24 optional :id, String |
#name ⇒ String?
Optional display name for the experiment.
30 |
# File 'lib/courier/models/journey_experiment.rb', line 30 optional :name, String |
#variants ⇒ Array<Courier::Models::JourneyExperimentVariant>
Between 2 and 10 weighted template variants.
17 |
# File 'lib/courier/models/journey_experiment.rb', line 17 required :variants, -> { Courier::Internal::Type::ArrayOf[Courier::JourneyExperimentVariant] } |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/courier/models/journey_experiment.rbs', line 31
def to_hash: -> {
|