Class: Courier::Models::JourneyFetchPostPutNode

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/journey_fetch_post_put_node.rb

Defined Under Namespace

Modules: Method, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(merge_strategy:, method_:, type:, url:, id: nil, body: nil, conditions: nil, headers: nil, query_params: nil, response_schema: nil) ⇒ Object

Some parameter documentations has been truncated, see Courier::Models::JourneyFetchPostPutNode for more details.

Issue an HTTP POST or PUT request with a ‘body` and merge the response into the journey state per `merge_strategy`.

Parameters:



# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 61

Instance Attribute Details

#bodyString?

Returns:

  • (String, nil)


35
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 35

optional :body, String

#conditionsArray<String>, ...

Condition spec for a journey node. Accepts a single condition atom, an AND/OR group, or an AND/OR nested group. Omit the ‘conditions` property entirely to express “no conditions”.



43
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 43

optional :conditions, union: -> { Courier::JourneyConditionsField }

#headersHash{Symbol=>String}?

Returns:

  • (Hash{Symbol=>String}, nil)


48
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 48

optional :headers, Courier::Internal::Type::HashOf[String]

#idString?

Returns:

  • (String, nil)


30
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 30

optional :id, String

#merge_strategySymbol, Courier::Models::JourneyMergeStrategy

Strategy for merging a fetch response into the journey run state.



10
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 10

required :merge_strategy, enum: -> { Courier::JourneyMergeStrategy }

#method_Symbol, Courier::Models::JourneyFetchPostPutNode::Method



15
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 15

required :method_, enum: -> { Courier::JourneyFetchPostPutNode::Method }, api_name: :method

#query_paramsHash{Symbol=>String}?

Returns:

  • (Hash{Symbol=>String}, nil)


53
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 53

optional :query_params, Courier::Internal::Type::HashOf[String]

#response_schemaHash{Symbol=>Object}?

A JSONSchema object (Draft-07-compatible). Validated at runtime by Ajv.

Returns:

  • (Hash{Symbol=>Object}, nil)


59
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 59

optional :response_schema, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown]

#typeSymbol, Courier::Models::JourneyFetchPostPutNode::Type



20
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 20

required :type, enum: -> { Courier::JourneyFetchPostPutNode::Type }

#urlString

Returns:

  • (String)


25
# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 25

required :url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/courier/models/journey_fetch_post_put_node.rb', line 95