Class: Courier::Models::JourneyNode::JourneyAddToDigestNode
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::JourneyNode::JourneyAddToDigestNode
- Defined in:
- lib/courier/models/journey_node.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#conditions ⇒ Array<String>, ...
Condition spec for a journey node.
- #id ⇒ String?
-
#subscription_topic_id ⇒ String
The subscription topic that owns the digest the event is added to.
- #type ⇒ Symbol, Courier::Models::JourneyNode::JourneyAddToDigestNode::Type
Instance Method Summary collapse
-
#initialize(subscription_topic_id:, type:, id: nil, conditions: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see JourneyAddToDigestNode for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(subscription_topic_id:, type:, id: nil, conditions: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::JourneyNode::JourneyAddToDigestNode for more details.
Add the current event to a digest keyed by the given subscription topic. The digest accumulates events and releases them on the schedule configured for the topic.
|
|
# File 'lib/courier/models/journey_node.rb', line 231
|
Instance Attribute Details
#conditions ⇒ Array<String>, ...
Condition spec for a journey node. Accepts a single condition atom, an AND/OR group, or an AND/OR nested group. Omit the ‘conditions` property entirely to express “no conditions”.
229 |
# File 'lib/courier/models/journey_node.rb', line 229 optional :conditions, union: -> { Courier::JourneyConditionsField } |
#id ⇒ String?
221 |
# File 'lib/courier/models/journey_node.rb', line 221 optional :id, String |
#subscription_topic_id ⇒ String
The subscription topic that owns the digest the event is added to.
211 |
# File 'lib/courier/models/journey_node.rb', line 211 required :subscription_topic_id, String |
#type ⇒ Symbol, Courier::Models::JourneyNode::JourneyAddToDigestNode::Type
216 |
# File 'lib/courier/models/journey_node.rb', line 216 required :type, enum: -> { Courier::JourneyNode::JourneyAddToDigestNode::Type } |