Class: Courier::Models::JourneyRunListItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::JourneyRunListItem
- Defined in:
- lib/courier/models/journey_run_list_item.rb,
sig/courier/models/journey_run_list_item.rbs
Instance Attribute Summary collapse
-
#created_at ⇒ String?
When the run started, as an ISO 8601 timestamp.
-
#run_id ⇒ String
A unique identifier representing the run.
-
#source ⇒ Array<String>
Internal provenance strings describing what started the run.
-
#status ⇒ String?
The state of the run.
-
#template_id ⇒ String?
The id of the Journey this run belongs to.
Instance Method Summary collapse
-
#initialize(run_id:, source:, created_at: nil, status: nil, template_id: nil) ⇒ Object
constructor
A Journey run as it appears in a list response, without
updated_at. - #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(run_id:, source:, created_at: nil, status: nil, template_id: nil) ⇒ Object
A Journey run as it appears in a list response, without updated_at.
|
|
# File 'lib/courier/models/journey_run_list_item.rb', line 36
|
Instance Attribute Details
#created_at ⇒ String?
When the run started, as an ISO 8601 timestamp.
22 |
# File 'lib/courier/models/journey_run_list_item.rb', line 22 optional :created_at, String |
#run_id ⇒ String
A unique identifier representing the run.
10 |
# File 'lib/courier/models/journey_run_list_item.rb', line 10 required :run_id, String |
#source ⇒ Array<String>
Internal provenance strings describing what started the run. Diagnostic only.
16 |
# File 'lib/courier/models/journey_run_list_item.rb', line 16 required :source, Courier::Internal::Type::ArrayOf[String] |
#status ⇒ String?
The state of the run. See JourneyRun.status for the values it takes.
28 |
# File 'lib/courier/models/journey_run_list_item.rb', line 28 optional :status, String |
#template_id ⇒ String?
The id of the Journey this run belongs to.
34 |
# File 'lib/courier/models/journey_run_list_item.rb', line 34 optional :template_id, String |
Instance Method Details
#to_hash ⇒ {
37 |
# File 'sig/courier/models/journey_run_list_item.rbs', line 37
def to_hash: -> {
|