Class: Courier::Models::JourneySendNodeToSlackEmail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::JourneySendNodeToSlackEmail
- Defined in:
- lib/courier/models/journey_send_node_to_slack_email.rb,
sig/courier/models/journey_send_node_to_slack_email.rbs
Instance Attribute Summary collapse
-
#access_token ⇒ String?
A runtime reference to a Slack access token, such as
{{data.slack_token}}. -
#email ⇒ String
Email address of the Slack user to send to, resolved via the workspace directory.
Instance Method Summary collapse
-
#initialize(email:, access_token: nil) ⇒ JourneySendNodeToSlackEmail
constructor
Some parameter documentations has been truncated, see JourneySendNodeToSlackEmail for more details.
- #to_hash ⇒ { email: String, access_token: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(email:, access_token: nil) ⇒ JourneySendNodeToSlackEmail
Some parameter documentations has been truncated, see Courier::Models::JourneySendNodeToSlackEmail for more details.
|
|
# File 'lib/courier/models/journey_send_node_to_slack_email.rb', line 21
|
Instance Attribute Details
#access_token ⇒ String?
A runtime reference to a Slack access token, such as {{data.slack_token}}.
Literal values are rejected — they'd be stored permanently with no way to rotate
them. Omit to use the token on the recipient's stored Slack profile.
19 |
# File 'lib/courier/models/journey_send_node_to_slack_email.rb', line 19 optional :access_token, String |
#email ⇒ String
Email address of the Slack user to send to, resolved via the workspace directory.
11 |
# File 'lib/courier/models/journey_send_node_to_slack_email.rb', line 11 required :email, String |
Instance Method Details
#to_hash ⇒ { email: String, access_token: String }
15 |
# File 'sig/courier/models/journey_send_node_to_slack_email.rbs', line 15
def to_hash: -> { email: String, access_token: String }
|