Class: Courier::Models::JourneySendNodeToSlackUserID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::JourneySendNodeToSlackUserID
- Defined in:
- lib/courier/models/journey_send_node_to_slack_user_id.rb,
sig/courier/models/journey_send_node_to_slack_user_id.rbs
Instance Attribute Summary collapse
-
#access_token ⇒ String?
A runtime reference to a Slack access token, such as
{{data.slack_token}}. -
#user_id ⇒ String
Slack user ID to send to.
Instance Method Summary collapse
-
#initialize(user_id:, access_token: nil) ⇒ JourneySendNodeToSlackUserID
constructor
Some parameter documentations has been truncated, see JourneySendNodeToSlackUserID for more details.
- #to_hash ⇒ { user_id: String, access_token: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(user_id:, access_token: nil) ⇒ JourneySendNodeToSlackUserID
Some parameter documentations has been truncated, see Courier::Models::JourneySendNodeToSlackUserID for more details.
|
|
# File 'lib/courier/models/journey_send_node_to_slack_user_id.rb', line 20
|
Instance Attribute Details
#access_token ⇒ String?
A runtime reference to a Slack access token, such as {{data.slack_token}}.
Literal values are rejected — they'd be stored permanently with no way to rotate
them. Omit to use the token on the recipient's stored Slack profile.
18 |
# File 'lib/courier/models/journey_send_node_to_slack_user_id.rb', line 18 optional :access_token, String |
#user_id ⇒ String
Slack user ID to send to.
10 |
# File 'lib/courier/models/journey_send_node_to_slack_user_id.rb', line 10 required :user_id, String |
Instance Method Details
#to_hash ⇒ { user_id: String, access_token: String }
15 |
# File 'sig/courier/models/journey_send_node_to_slack_user_id.rbs', line 15
def to_hash: -> { user_id: String, access_token: String }
|