Class: Courier::Models::PreferenceSectionGetResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::PreferenceSectionGetResponse
- Defined in:
- lib/courier/models/preference_section_get_response.rb
Overview
Instance Attribute Summary collapse
-
#created ⇒ String
ISO-8601 timestamp of when the section was created.
-
#creator ⇒ String?
Id of the creator.
-
#has_custom_routing ⇒ Boolean
Whether the section defines custom routing for its topics.
-
#id ⇒ String
The preference section id.
-
#name ⇒ String
Human-readable name.
-
#routing_options ⇒ Array<Symbol, Courier::Models::ChannelClassification>
Default channels for the section.
-
#topics ⇒ Array<Courier::Models::PreferenceTopicGetResponse>
The topics contained in this section.
-
#updated ⇒ String?
ISO-8601 timestamp of the last update.
-
#updater ⇒ String?
Id of the last updater.
Instance Method Summary collapse
-
#initialize(id:, created:, has_custom_routing:, name:, routing_options:, topics:, creator: nil, updated: nil, updater: nil) ⇒ Object
constructor
A preference section in your workspace, including its topics.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created:, has_custom_routing:, name:, routing_options:, topics:, creator: nil, updated: nil, updater: nil) ⇒ Object
A preference section in your workspace, including its topics.
|
|
# File 'lib/courier/models/preference_section_get_response.rb', line 61
|
Instance Attribute Details
#created ⇒ String
ISO-8601 timestamp of when the section was created.
17 |
# File 'lib/courier/models/preference_section_get_response.rb', line 17 required :created, String |
#creator ⇒ String?
Id of the creator.
47 |
# File 'lib/courier/models/preference_section_get_response.rb', line 47 optional :creator, String, nil?: true |
#has_custom_routing ⇒ Boolean
Whether the section defines custom routing for its topics.
23 |
# File 'lib/courier/models/preference_section_get_response.rb', line 23 required :has_custom_routing, Courier::Internal::Type::Boolean |
#id ⇒ String
The preference section id.
11 |
# File 'lib/courier/models/preference_section_get_response.rb', line 11 required :id, String |
#name ⇒ String
Human-readable name.
29 |
# File 'lib/courier/models/preference_section_get_response.rb', line 29 required :name, String |
#routing_options ⇒ Array<Symbol, Courier::Models::ChannelClassification>
Default channels for the section. May be empty.
35 |
# File 'lib/courier/models/preference_section_get_response.rb', line 35 required :routing_options, -> { Courier::Internal::Type::ArrayOf[enum: Courier::ChannelClassification] } |
#topics ⇒ Array<Courier::Models::PreferenceTopicGetResponse>
The topics contained in this section.
41 |
# File 'lib/courier/models/preference_section_get_response.rb', line 41 required :topics, -> { Courier::Internal::Type::ArrayOf[Courier::PreferenceTopicGetResponse] } |
#updated ⇒ String?
ISO-8601 timestamp of the last update.
53 |
# File 'lib/courier/models/preference_section_get_response.rb', line 53 optional :updated, String, nil?: true |
#updater ⇒ String?
Id of the last updater.
59 |
# File 'lib/courier/models/preference_section_get_response.rb', line 59 optional :updater, String, nil?: true |