Class: Courier::Models::PreferenceTopicGetResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::PreferenceTopicGetResponse
- Defined in:
- lib/courier/models/preference_topic_get_response.rb
Defined Under Namespace
Modules: AllowedPreference, DefaultStatus
Instance Attribute Summary collapse
-
#allowed_preferences ⇒ Array<Symbol, Courier::Models::PreferenceTopicGetResponse::AllowedPreference>
Preference controls a recipient may customize.
-
#created ⇒ String
ISO-8601 timestamp of when the topic was created.
-
#creator ⇒ String?
Id of the creator.
-
#default_status ⇒ Symbol, Courier::Models::PreferenceTopicGetResponse::DefaultStatus
The default subscription status applied when a recipient has not set their own.
-
#id ⇒ String
The preference topic id.
-
#include_unsubscribe_header ⇒ Boolean
Whether a list-unsubscribe header is included on emails for this topic.
-
#name ⇒ String
Human-readable name.
-
#routing_options ⇒ Array<Symbol, Courier::Models::ChannelClassification>
Default channels delivered for this topic.
-
#topic_data ⇒ Hash{Symbol=>Object}
Arbitrary metadata associated with the topic.
-
#updated ⇒ String
ISO-8601 timestamp of the last update.
-
#updater ⇒ String?
Id of the last updater.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, allowed_preferences:, created:, default_status:, include_unsubscribe_header:, name:, routing_options:, topic_data:, updated:, creator: nil, updater: nil) ⇒ Object
constructor
A subscription preference topic in your workspace.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, allowed_preferences:, created:, default_status:, include_unsubscribe_header:, name:, routing_options:, topic_data:, updated:, creator: nil, updater: nil) ⇒ Object
A subscription preference topic in your workspace.
|
|
# File 'lib/courier/models/preference_topic_get_response.rb', line 73
|
Instance Attribute Details
#allowed_preferences ⇒ Array<Symbol, Courier::Models::PreferenceTopicGetResponse::AllowedPreference>
Preference controls a recipient may customize. May be empty.
16 17 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 16 required :allowed_preferences, -> { Courier::Internal::Type::ArrayOf[enum: Courier::PreferenceTopicGetResponse::AllowedPreference] } |
#created ⇒ String
ISO-8601 timestamp of when the topic was created.
23 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 23 required :created, String |
#creator ⇒ String?
Id of the creator.
65 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 65 optional :creator, String, nil?: true |
#default_status ⇒ Symbol, Courier::Models::PreferenceTopicGetResponse::DefaultStatus
The default subscription status applied when a recipient has not set their own.
29 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 29 required :default_status, enum: -> { Courier::PreferenceTopicGetResponse::DefaultStatus } |
#id ⇒ String
The preference topic id.
10 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 10 required :id, String |
#include_unsubscribe_header ⇒ Boolean
Whether a list-unsubscribe header is included on emails for this topic.
35 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 35 required :include_unsubscribe_header, Courier::Internal::Type::Boolean |
#name ⇒ String
Human-readable name.
41 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 41 required :name, String |
#routing_options ⇒ Array<Symbol, Courier::Models::ChannelClassification>
Default channels delivered for this topic. May be empty.
47 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 47 required :routing_options, -> { Courier::Internal::Type::ArrayOf[enum: Courier::ChannelClassification] } |
#topic_data ⇒ Hash{Symbol=>Object}
Arbitrary metadata associated with the topic.
53 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 53 required :topic_data, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown] |
#updated ⇒ String
ISO-8601 timestamp of the last update.
59 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 59 required :updated, String |
#updater ⇒ String?
Id of the last updater.
71 |
# File 'lib/courier/models/preference_topic_get_response.rb', line 71 optional :updater, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/courier/models/preference_topic_get_response.rb', line 105
|