Class: Courier::Models::ProvidersCatalogEntry::Setting

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/courier/models/providers_catalog_entry.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(required:, type:, values: nil) ⇒ Object

Describes a single configuration field in the provider catalog.

Parameters:

  • required (Boolean)

    Whether this field is required when configuring the provider.

  • type (String)

    The field’s data type (e.g. “string”, “boolean”, “enum”).

  • values (Array<String>) (defaults to: nil)

    Allowed values when ‘type` is “enum”.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/courier/models/providers_catalog_entry.rb', line 56

class Setting < Courier::Internal::Type::BaseModel
  # @!attribute required
  #   Whether this field is required when configuring the provider.
  #
  #   @return [Boolean]
  required :required, Courier::Internal::Type::Boolean

  # @!attribute type
  #   The field's data type (e.g. "string", "boolean", "enum").
  #
  #   @return [String]
  required :type, String

  # @!attribute values
  #   Allowed values when `type` is "enum".
  #
  #   @return [Array<String>, nil]
  optional :values, Courier::Internal::Type::ArrayOf[String]

  # @!method initialize(required:, type:, values: nil)
  #   Describes a single configuration field in the provider catalog.
  #
  #   @param required [Boolean] Whether this field is required when configuring the provider.
  #
  #   @param type [String] The field's data type (e.g. "string", "boolean", "enum").
  #
  #   @param values [Array<String>] Allowed values when `type` is "enum".
end

Instance Attribute Details

#requiredBoolean

Whether this field is required when configuring the provider.

Returns:

  • (Boolean)


61
# File 'lib/courier/models/providers_catalog_entry.rb', line 61

required :required, Courier::Internal::Type::Boolean

#typeString

The field’s data type (e.g. “string”, “boolean”, “enum”).

Returns:

  • (String)


67
# File 'lib/courier/models/providers_catalog_entry.rb', line 67

required :type, String

#valuesArray<String>?

Allowed values when ‘type` is “enum”.

Returns:

  • (Array<String>, nil)


73
# File 'lib/courier/models/providers_catalog_entry.rb', line 73

optional :values, Courier::Internal::Type::ArrayOf[String]