Class: Courier::Models::PutTenantTemplateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::PutTenantTemplateRequest
- Defined in:
- lib/courier/models/put_tenant_template_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#published ⇒ Boolean?
Whether to publish the template immediately after saving.
-
#template ⇒ Courier::Models::TenantTemplateInput
Template configuration for creating or updating a tenant notification template.
Instance Method Summary collapse
-
#initialize(template:, published: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PutTenantTemplateRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(template:, published: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::PutTenantTemplateRequest for more details.
Request body for creating or updating a tenant notification template
|
|
# File 'lib/courier/models/put_tenant_template_request.rb', line 20
|
Instance Attribute Details
#published ⇒ Boolean?
Whether to publish the template immediately after saving. When true, the template becomes the active/published version. When false (default), the template is saved as a draft.
18 |
# File 'lib/courier/models/put_tenant_template_request.rb', line 18 optional :published, Courier::Internal::Type::Boolean |
#template ⇒ Courier::Models::TenantTemplateInput
Template configuration for creating or updating a tenant notification template
10 |
# File 'lib/courier/models/put_tenant_template_request.rb', line 10 required :template, -> { Courier::TenantTemplateInput } |