Class: Courier::Models::PutTenantTemplateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::PutTenantTemplateResponse
- Defined in:
- lib/courier/models/put_tenant_template_response.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The template ID.
-
#published_at ⇒ String?
The timestamp when the template was published.
-
#version ⇒ String
The version of the saved template.
Instance Method Summary collapse
-
#initialize(id:, version:, published_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PutTenantTemplateResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, version:, published_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::PutTenantTemplateResponse for more details.
Response from creating or updating a tenant notification template
|
|
# File 'lib/courier/models/put_tenant_template_response.rb', line 25
|
Instance Attribute Details
#id ⇒ String
The template ID
10 |
# File 'lib/courier/models/put_tenant_template_response.rb', line 10 required :id, String |
#published_at ⇒ String?
The timestamp when the template was published. Only present if the template was published as part of this request.
23 |
# File 'lib/courier/models/put_tenant_template_response.rb', line 23 optional :published_at, String, nil?: true |
#version ⇒ String
The version of the saved template
16 |
# File 'lib/courier/models/put_tenant_template_response.rb', line 16 required :version, String |