Class: Courier::Models::ScheduleBroadcastRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::ScheduleBroadcastRequest
- Defined in:
- lib/courier/models/schedule_broadcast_request.rb,
sig/courier/models/schedule_broadcast_request.rbs
Direct Known Subclasses
Defined Under Namespace
Modules: RecipientType
Instance Attribute Summary collapse
-
#recipient_id ⇒ String
ID of the target list or audience.
-
#recipient_type ⇒ Symbol, Courier::Models::ScheduleBroadcastRequest::RecipientType
Whether the broadcast targets a list or an audience.
-
#scheduled_to ⇒ String
Wall-clock timestamp of the future send, no timezone offset (e.g. "2026-07-21T20:00:00").
-
#timezone ⇒ String?
IANA timezone for the scheduled send (e.g. America/New_York).
Instance Method Summary collapse
-
#initialize(recipient_id:, recipient_type:, scheduled_to:, timezone: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ScheduleBroadcastRequest for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(recipient_id:, recipient_type:, scheduled_to:, timezone: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::ScheduleBroadcastRequest for more details.
Request body for scheduling a broadcast for a future send.
|
|
# File 'lib/courier/models/schedule_broadcast_request.rb', line 31
|
Instance Attribute Details
#recipient_id ⇒ String
ID of the target list or audience.
10 |
# File 'lib/courier/models/schedule_broadcast_request.rb', line 10 required :recipient_id, String |
#recipient_type ⇒ Symbol, Courier::Models::ScheduleBroadcastRequest::RecipientType
Whether the broadcast targets a list or an audience.
16 |
# File 'lib/courier/models/schedule_broadcast_request.rb', line 16 required :recipient_type, enum: -> { Courier::ScheduleBroadcastRequest::RecipientType } |
#scheduled_to ⇒ String
Wall-clock timestamp of the future send, no timezone offset (e.g.
"2026-07-21T20:00:00"). The zone is given by timezone.
23 |
# File 'lib/courier/models/schedule_broadcast_request.rb', line 23 required :scheduled_to, String |
#timezone ⇒ String?
IANA timezone for the scheduled send (e.g. America/New_York).
29 |
# File 'lib/courier/models/schedule_broadcast_request.rb', line 29 optional :timezone, String |
Instance Method Details
#to_hash ⇒ {
29 |
# File 'sig/courier/models/schedule_broadcast_request.rbs', line 29
def to_hash: -> {
|