Module: Courier::Models::SendMessageParams::Message::To::UnionMember8
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/courier/models/send_message_params.rb,
sig/courier/models/send_message_params.rbs
Overview
A single recipient of the message. Choose one of the following types based on how you want to identify the recipient: - User: Send to a specific user by user_id, email, or phone number - Audience: Send to all users in an audience - List: Send to all users in a list - List Pattern: Send to users in lists matching a pattern - Slack: Send via Slack (channel, email, or user_id) - MS Teams: Send via Microsoft Teams - PagerDuty: Send via PagerDuty - Webhook: Send via webhook
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.variants ⇒ ::Array[Courier::Models::SendMessageParams::Message::To::union_member8]
321 |
# File 'sig/courier/models/send_message_params.rbs', line 321
def self?.variants: -> ::Array[Courier::Models::SendMessageParams::Message::To::union_member8]
|