Class: Courier::Models::SubscriptionTopicNew
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::SubscriptionTopicNew
- Defined in:
- lib/courier/models/subscription_topic_new.rb
Direct Known Subclasses
DefaultPreferences::Item, Tenants::Preferences::ItemUpdateParams
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#custom_routing ⇒ Array<Symbol, Courier::Models::ChannelClassification>?
The default channels to send to this tenant when has_custom_routing is enabled.
-
#has_custom_routing ⇒ Boolean?
Override channel routing with custom preferences.
- #status ⇒ Symbol, Courier::Models::SubscriptionTopicNew::Status
Instance Method Summary collapse
-
#initialize(status:, custom_routing: nil, has_custom_routing: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubscriptionTopicNew for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(status:, custom_routing: nil, has_custom_routing: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::SubscriptionTopicNew for more details.
|
|
# File 'lib/courier/models/subscription_topic_new.rb', line 27
|
Instance Attribute Details
#custom_routing ⇒ Array<Symbol, Courier::Models::ChannelClassification>?
The default channels to send to this tenant when has_custom_routing is enabled
15 16 17 |
# File 'lib/courier/models/subscription_topic_new.rb', line 15 optional :custom_routing, -> { Courier::Internal::Type::ArrayOf[enum: Courier::ChannelClassification] }, nil?: true |
#has_custom_routing ⇒ Boolean?
Override channel routing with custom preferences. This will override any template preferences that are set, but a user can still customize their preferences
25 |
# File 'lib/courier/models/subscription_topic_new.rb', line 25 optional :has_custom_routing, Courier::Internal::Type::Boolean, nil?: true |
#status ⇒ Symbol, Courier::Models::SubscriptionTopicNew::Status
9 |
# File 'lib/courier/models/subscription_topic_new.rb', line 9 required :status, enum: -> { Courier::SubscriptionTopicNew::Status } |