Class: Courier::Models::TenantAssociation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::TenantAssociation
- Defined in:
- lib/courier/models/tenant_association.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#profile ⇒ Hash{Symbol=>Object}?
Additional metadata to be applied to a user profile when used in a tenant context.
-
#tenant_id ⇒ String
Tenant ID for the association between tenant and user.
- #type ⇒ Symbol, ...
-
#user_id ⇒ String?
User ID for the association between tenant and user.
Instance Method Summary collapse
-
#initialize(tenant_id:, profile: nil, type: nil, user_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TenantAssociation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tenant_id:, profile: nil, type: nil, user_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::TenantAssociation for more details.
|
|
# File 'lib/courier/models/tenant_association.rb', line 30
|
Instance Attribute Details
#profile ⇒ Hash{Symbol=>Object}?
Additional metadata to be applied to a user profile when used in a tenant context
17 |
# File 'lib/courier/models/tenant_association.rb', line 17 optional :profile, Courier::Internal::Type::HashOf[Courier::Internal::Type::Unknown], nil?: true |
#tenant_id ⇒ String
Tenant ID for the association between tenant and user
10 |
# File 'lib/courier/models/tenant_association.rb', line 10 required :tenant_id, String |
#type ⇒ Symbol, ...
22 |
# File 'lib/courier/models/tenant_association.rb', line 22 optional :type, enum: -> { Courier::TenantAssociation::Type }, nil?: true |
#user_id ⇒ String?
User ID for the association between tenant and user
28 |
# File 'lib/courier/models/tenant_association.rb', line 28 optional :user_id, String, nil?: true |