Class: Courier::Models::TenantTemplateInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::TenantTemplateInput
- Defined in:
- lib/courier/models/tenant_template_input.rb
Instance Attribute Summary collapse
-
#channels ⇒ Hash{Symbol=>Courier::Models::Channel}?
Channel-specific delivery configuration (email, SMS, push, etc.).
-
#content ⇒ Courier::Models::ElementalContent
Template content configuration including blocks, elements, and message structure.
-
#providers ⇒ Hash{Symbol=>Courier::Models::MessageProvidersType}?
Provider-specific delivery configuration for routing to specific email/SMS providers.
-
#routing ⇒ Courier::Models::MessageRouting?
Message routing configuration for multi-channel delivery strategies.
Instance Method Summary collapse
-
#initialize(content:, channels: nil, providers: nil, routing: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TenantTemplateInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content:, channels: nil, providers: nil, routing: nil) ⇒ Object
Some parameter documentations has been truncated, see Courier::Models::TenantTemplateInput for more details.
Template configuration for creating or updating a tenant notification template
|
|
# File 'lib/courier/models/tenant_template_input.rb', line 31
|
Instance Attribute Details
#channels ⇒ Hash{Symbol=>Courier::Models::Channel}?
Channel-specific delivery configuration (email, SMS, push, etc.)
16 |
# File 'lib/courier/models/tenant_template_input.rb', line 16 optional :channels, -> { Courier::Internal::Type::HashOf[Courier::Channel] } |
#content ⇒ Courier::Models::ElementalContent
Template content configuration including blocks, elements, and message structure
10 |
# File 'lib/courier/models/tenant_template_input.rb', line 10 required :content, -> { Courier::ElementalContent } |
#providers ⇒ Hash{Symbol=>Courier::Models::MessageProvidersType}?
Provider-specific delivery configuration for routing to specific email/SMS providers
23 |
# File 'lib/courier/models/tenant_template_input.rb', line 23 optional :providers, -> { Courier::Internal::Type::HashOf[Courier::MessageProvidersType] } |
#routing ⇒ Courier::Models::MessageRouting?
Message routing configuration for multi-channel delivery strategies
29 |
# File 'lib/courier/models/tenant_template_input.rb', line 29 optional :routing, -> { Courier::MessageRouting } |