Class: Courier::Models::Users::TokenAddSingleParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/courier/models/users/token_add_single_params.rb

Overview

Defined Under Namespace

Modules: ExpiryDate, ProviderKey Classes: Device, Tracking

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ad_id: nil, app_id: nil, device_id: nil, manufacturer: nil, model: nil, platform: nil) ⇒ Object

Information about the device the token came from.

Parameters:

  • ad_id (String, nil) (defaults to: nil)

    Id of the advertising identifier

  • app_id (String, nil) (defaults to: nil)

    Id of the application the token is used for

  • device_id (String, nil) (defaults to: nil)

    Id of the device the token is associated with

  • manufacturer (String, nil) (defaults to: nil)

    The device manufacturer

  • model (String, nil) (defaults to: nil)

    The device model

  • platform (String, nil) (defaults to: nil)

    The device platform i.e. android, ios, web



# File 'lib/courier/models/users/token_add_single_params.rb', line 120

Instance Attribute Details

#deviceCourier::Models::Users::TokenAddSingleParams::Device?

Information about the device the token came from.



30
# File 'lib/courier/models/users/token_add_single_params.rb', line 30

optional :device, -> { Courier::Users::TokenAddSingleParams::Device }, nil?: true

#expiry_dateString, ...

ISO 8601 formatted date the token expires. Defaults to 2 months. Set to false to disable expiration.

Returns:

  • (String, Boolean, nil)


37
# File 'lib/courier/models/users/token_add_single_params.rb', line 37

optional :expiry_date, union: -> { Courier::Users::TokenAddSingleParams::ExpiryDate }, nil?: true

#propertiesObject?

Properties about the token.

Returns:

  • (Object, nil)


43
# File 'lib/courier/models/users/token_add_single_params.rb', line 43

optional :properties, Courier::Internal::Type::Unknown

#provider_keySymbol, Courier::Models::Users::TokenAddSingleParams::ProviderKey



24
# File 'lib/courier/models/users/token_add_single_params.rb', line 24

required :provider_key, enum: -> { Courier::Users::TokenAddSingleParams::ProviderKey }

#tokenString

Returns:

  • (String)


19
# File 'lib/courier/models/users/token_add_single_params.rb', line 19

required :token, String

#trackingCourier::Models::Users::TokenAddSingleParams::Tracking?

Tracking information about the device the token came from.



49
# File 'lib/courier/models/users/token_add_single_params.rb', line 49

optional :tracking, -> { Courier::Users::TokenAddSingleParams::Tracking }, nil?: true

#user_idString

Returns:

  • (String)


14
# File 'lib/courier/models/users/token_add_single_params.rb', line 14

required :user_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/courier/models/users/token_add_single_params.rb', line 79

.variantsArray(String, Boolean)

Returns:

  • (Array(String, Boolean))


# File 'lib/courier/models/users/token_add_single_params.rb', line 145