Class: Courier::Models::Users::TokenAddSingleParams::Device
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Courier::Models::Users::TokenAddSingleParams::Device
- Defined in:
- lib/courier/models/users/token_add_single_params.rb
Instance Attribute Summary collapse
-
#ad_id ⇒ String?
Id of the advertising identifier.
-
#app_id ⇒ String?
Id of the application the token is used for.
-
#device_id ⇒ String?
Id of the device the token is associated with.
-
#manufacturer ⇒ String?
The device manufacturer.
-
#model ⇒ String?
The device model.
-
#platform ⇒ String?
The device platform i.e.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Courier::Internal::Type::BaseModel
Instance Attribute Details
#ad_id ⇒ String?
Id of the advertising identifier
88 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 88 optional :ad_id, String, nil?: true |
#app_id ⇒ String?
Id of the application the token is used for
94 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 94 optional :app_id, String, nil?: true |
#device_id ⇒ String?
Id of the device the token is associated with
100 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 100 optional :device_id, String, nil?: true |
#manufacturer ⇒ String?
The device manufacturer
106 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 106 optional :manufacturer, String, nil?: true |
#model ⇒ String?
The device model
112 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 112 optional :model, String, nil?: true |
#platform ⇒ String?
The device platform i.e. android, ios, web
118 |
# File 'lib/courier/models/users/token_add_single_params.rb', line 118 optional :platform, String, nil?: true |