Class: Courier::Resources::Notifications::Previews
- Inherits:
-
Object
- Object
- Courier::Resources::Notifications::Previews
- Defined in:
- lib/courier/resources/notifications/previews.rb,
lib/courier/resources/notifications/previews/runs.rb,
sig/courier/resources/notifications/previews.rbs,
sig/courier/resources/notifications/previews/runs.rbs
Defined Under Namespace
Classes: Runs
Instance Attribute Summary collapse
-
#runs ⇒ Courier::Resources::Notifications::Previews::Runs
readonly
Render a template's email content on real email clients and read back the screenshots, so you can check how it looks before you send it.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Previews
constructor
private
A new instance of Previews.
Constructor Details
#initialize(client:) ⇒ Previews
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Previews.
15 16 17 18 |
# File 'lib/courier/resources/notifications/previews.rb', line 15 def initialize(client:) @client = client @runs = Courier::Resources::Notifications::Previews::Runs.new(client: client) end |
Instance Attribute Details
#runs ⇒ Courier::Resources::Notifications::Previews::Runs (readonly)
Render a template's email content on real email clients and read back the screenshots, so you can check how it looks before you send it.
10 11 12 |
# File 'lib/courier/resources/notifications/previews.rb', line 10 def runs @runs end |