Class: Trycourier::Models::MessageDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Trycourier::Models::MessageDetails
- Defined in:
- lib/trycourier/models/message_details.rb
Direct Known Subclasses
Defined Under Namespace
Instance Attribute Summary collapse
-
#clicked ⇒ Integer
A UTC timestamp at which the recipient clicked on a tracked link for the first time.
-
#delivered ⇒ Integer
A UTC timestamp at which the Integration provider delivered the message.
-
#enqueued ⇒ Integer
A UTC timestamp at which Courier received the message request.
-
#error ⇒ String?
A message describing the error that occurred.
-
#event ⇒ String
A unique identifier associated with the event of the delivered message.
-
#id ⇒ String
A unique identifier associated with the message you wish to retrieve (results from a send).
-
#notification ⇒ String
A unique identifier associated with the notification of the delivered message.
-
#opened ⇒ Integer
A UTC timestamp at which the recipient opened a message for the first time.
-
#reason ⇒ Symbol, ...
The reason for the current status of the message.
-
#recipient ⇒ String
A unique identifier associated with the recipient of the delivered message.
-
#sent ⇒ Integer
A UTC timestamp at which Courier passed the message to the Integration provider.
-
#status ⇒ Symbol, Trycourier::Models::MessageDetails::Status
The current status of the message.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: , clicked: , delivered: , enqueued: , event: , notification: , opened: , recipient: , sent: , status: , error: nil, reason: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessageDetails for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , clicked: , delivered: , enqueued: , event: , notification: , opened: , recipient: , sent: , status: , error: nil, reason: nil) ⇒ Object
Some parameter documentations has been truncated, see Trycourier::Models::MessageDetails for more details.
|
|
# File 'lib/trycourier/models/message_details.rb', line 84
|
Instance Attribute Details
#clicked ⇒ Integer
A UTC timestamp at which the recipient clicked on a tracked link for the first time. Stored as a millisecond representation of the Unix epoch.
18 |
# File 'lib/trycourier/models/message_details.rb', line 18 required :clicked, Integer |
#delivered ⇒ Integer
A UTC timestamp at which the Integration provider delivered the message. Stored as a millisecond representation of the Unix epoch.
25 |
# File 'lib/trycourier/models/message_details.rb', line 25 required :delivered, Integer |
#enqueued ⇒ Integer
A UTC timestamp at which Courier received the message request. Stored as a millisecond representation of the Unix epoch.
32 |
# File 'lib/trycourier/models/message_details.rb', line 32 required :enqueued, Integer |
#error ⇒ String?
A message describing the error that occurred.
76 |
# File 'lib/trycourier/models/message_details.rb', line 76 optional :error, String, nil?: true |
#event ⇒ String
A unique identifier associated with the event of the delivered message.
38 |
# File 'lib/trycourier/models/message_details.rb', line 38 required :event, String |
#id ⇒ String
A unique identifier associated with the message you wish to retrieve (results from a send).
11 |
# File 'lib/trycourier/models/message_details.rb', line 11 required :id, String |
#notification ⇒ String
A unique identifier associated with the notification of the delivered message.
44 |
# File 'lib/trycourier/models/message_details.rb', line 44 required :notification, String |
#opened ⇒ Integer
A UTC timestamp at which the recipient opened a message for the first time. Stored as a millisecond representation of the Unix epoch.
51 |
# File 'lib/trycourier/models/message_details.rb', line 51 required :opened, Integer |
#reason ⇒ Symbol, ...
The reason for the current status of the message.
82 |
# File 'lib/trycourier/models/message_details.rb', line 82 optional :reason, enum: -> { Trycourier::MessageDetails::Reason }, nil?: true |
#recipient ⇒ String
A unique identifier associated with the recipient of the delivered message.
57 |
# File 'lib/trycourier/models/message_details.rb', line 57 required :recipient, String |
#sent ⇒ Integer
A UTC timestamp at which Courier passed the message to the Integration provider. Stored as a millisecond representation of the Unix epoch.
64 |
# File 'lib/trycourier/models/message_details.rb', line 64 required :sent, Integer |
#status ⇒ Symbol, Trycourier::Models::MessageDetails::Status
The current status of the message.
70 |
# File 'lib/trycourier/models/message_details.rb', line 70 required :status, enum: -> { Trycourier::MessageDetails::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/trycourier/models/message_details.rb', line 134
|