Class: Trycourier::Models::UserToken
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Trycourier::Models::UserToken
- Defined in:
- lib/trycourier/models/user_token.rb
Direct Known Subclasses
Trycourier::Models::Users::TokenAddSingleParams, Trycourier::Models::Users::TokenRetrieveResponse
Defined Under Namespace
Modules: ExpiryDate, ProviderKey Classes: Device, Tracking
Instance Attribute Summary collapse
-
#device ⇒ Trycourier::Models::UserToken::Device?
Information about the device the token is associated with.
-
#expiry_date ⇒ String, ...
ISO 8601 formatted date the token expires.
-
#properties ⇒ Object?
Properties sent to the provider along with the token.
- #provider_key ⇒ Symbol, Trycourier::Models::UserToken::ProviderKey
-
#token ⇒ String?
Full body of the token.
-
#tracking ⇒ Trycourier::Models::UserToken::Tracking?
Information about the device the token is associated with.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ad_id: nil, app_id: nil, device_id: nil, manufacturer: nil, model: nil, platform: nil) ⇒ Object
constructor
Information about the device the token is associated with.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ad_id: nil, app_id: nil, device_id: nil, manufacturer: nil, model: nil, platform: nil) ⇒ Object
Information about the device the token is associated with.
|
|
# File 'lib/trycourier/models/user_token.rb', line 42
|
Instance Attribute Details
#device ⇒ Trycourier::Models::UserToken::Device?
Information about the device the token is associated with.
21 |
# File 'lib/trycourier/models/user_token.rb', line 21 optional :device, -> { Trycourier::UserToken::Device }, nil?: true |
#expiry_date ⇒ String, ...
ISO 8601 formatted date the token expires. Defaults to 2 months. Set to false to disable expiration.
28 |
# File 'lib/trycourier/models/user_token.rb', line 28 optional :expiry_date, union: -> { Trycourier::UserToken::ExpiryDate }, nil?: true |
#properties ⇒ Object?
Properties sent to the provider along with the token
34 |
# File 'lib/trycourier/models/user_token.rb', line 34 optional :properties, Trycourier::Internal::Type::Unknown |
#provider_key ⇒ Symbol, Trycourier::Models::UserToken::ProviderKey
9 |
# File 'lib/trycourier/models/user_token.rb', line 9 required :provider_key, enum: -> { Trycourier::UserToken::ProviderKey } |
#token ⇒ String?
Full body of the token. Must match token in URL.
15 |
# File 'lib/trycourier/models/user_token.rb', line 15 optional :token, String, nil?: true |
#tracking ⇒ Trycourier::Models::UserToken::Tracking?
Information about the device the token is associated with.
40 |
# File 'lib/trycourier/models/user_token.rb', line 40 optional :tracking, -> { Trycourier::UserToken::Tracking }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/trycourier/models/user_token.rb', line 67
|
.variants ⇒ Array(String, Boolean)
|
|
# File 'lib/trycourier/models/user_token.rb', line 136
|